# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer
from .validators.dlm import (
    validate_interval,
    validate_interval_unit,
    validate_state,
    validate_tags_or_list,
)


class Exclusions(AWSProperty):
    """
    `Exclusions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-exclusions.html>`__
    """

    props: PropsDictType = {
        "ExcludeBootVolumes": (boolean, False),
        "ExcludeTags": ([], False),
        "ExcludeVolumeTypes": ([], False),
    }


class CrossRegionCopyRetainRule(AWSProperty):
    """
    `CrossRegionCopyRetainRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyretainrule.html>`__
    """

    props: PropsDictType = {
        "Interval": (integer, True),
        "IntervalUnit": (str, True),
    }


class EncryptionConfiguration(AWSProperty):
    """
    `EncryptionConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-encryptionconfiguration.html>`__
    """

    props: PropsDictType = {
        "CmkArn": (str, False),
        "Encrypted": (boolean, True),
    }


class CrossRegionCopyAction(AWSProperty):
    """
    `CrossRegionCopyAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyaction.html>`__
    """

    props: PropsDictType = {
        "EncryptionConfiguration": (EncryptionConfiguration, True),
        "RetainRule": (CrossRegionCopyRetainRule, False),
        "Target": (str, True),
    }


class Action(AWSProperty):
    """
    `Action <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-action.html>`__
    """

    props: PropsDictType = {
        "CrossRegionCopy": ([CrossRegionCopyAction], True),
        "Name": (str, True),
    }


class EventParameters(AWSProperty):
    """
    `EventParameters <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-eventparameters.html>`__
    """

    props: PropsDictType = {
        "DescriptionRegex": (str, False),
        "EventType": (str, True),
        "SnapshotOwner": ([str], True),
    }


class EventSource(AWSProperty):
    """
    `EventSource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-eventsource.html>`__
    """

    props: PropsDictType = {
        "Parameters": (EventParameters, False),
        "Type": (str, True),
    }


class Parameters(AWSProperty):
    """
    `Parameters <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-parameters.html>`__
    """

    props: PropsDictType = {
        "ExcludeBootVolume": (boolean, False),
        "ExcludeDataVolumeTags": (Tags, False),
        "NoReboot": (boolean, False),
    }


class RetentionArchiveTier(AWSProperty):
    """
    `RetentionArchiveTier <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-retentionarchivetier.html>`__
    """

    props: PropsDictType = {
        "Count": (integer, False),
        "Interval": (integer, False),
        "IntervalUnit": (str, False),
    }


class ArchiveRetainRule(AWSProperty):
    """
    `ArchiveRetainRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-archiveretainrule.html>`__
    """

    props: PropsDictType = {
        "RetentionArchiveTier": (RetentionArchiveTier, True),
    }


class ArchiveRule(AWSProperty):
    """
    `ArchiveRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-archiverule.html>`__
    """

    props: PropsDictType = {
        "RetainRule": (ArchiveRetainRule, True),
    }


class Script(AWSProperty):
    """
    `Script <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-script.html>`__
    """

    props: PropsDictType = {
        "ExecuteOperationOnScriptFailure": (boolean, False),
        "ExecutionHandler": (str, False),
        "ExecutionHandlerService": (str, False),
        "ExecutionTimeout": (integer, False),
        "MaximumRetryCount": (integer, False),
        "Stages": ([str], False),
    }


class CreateRule(AWSProperty):
    """
    `CreateRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-createrule.html>`__
    """

    props: PropsDictType = {
        "CronExpression": (str, False),
        "Interval": (validate_interval, False),
        "IntervalUnit": (validate_interval_unit, False),
        "Location": (str, False),
        "Scripts": ([Script], False),
        "Times": ([str], False),
    }


class CrossRegionCopyDeprecateRule(AWSProperty):
    """
    `CrossRegionCopyDeprecateRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopydeprecaterule.html>`__
    """

    props: PropsDictType = {
        "Interval": (integer, True),
        "IntervalUnit": (str, True),
    }


class CrossRegionCopyRule(AWSProperty):
    """
    `CrossRegionCopyRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopyrule.html>`__
    """

    props: PropsDictType = {
        "CmkArn": (str, False),
        "CopyTags": (boolean, False),
        "DeprecateRule": (CrossRegionCopyDeprecateRule, False),
        "Encrypted": (boolean, True),
        "RetainRule": (CrossRegionCopyRetainRule, False),
        "Target": (str, False),
        "TargetRegion": (str, False),
    }


class DeprecateRule(AWSProperty):
    """
    `DeprecateRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-deprecaterule.html>`__
    """

    props: PropsDictType = {
        "Count": (integer, False),
        "Interval": (integer, False),
        "IntervalUnit": (str, False),
    }


class FastRestoreRule(AWSProperty):
    """
    `FastRestoreRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-fastrestorerule.html>`__
    """

    props: PropsDictType = {
        "AvailabilityZones": ([str], False),
        "Count": (integer, False),
        "Interval": (integer, False),
        "IntervalUnit": (str, False),
    }


class RetainRule(AWSProperty):
    """
    `RetainRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-retainrule.html>`__
    """

    props: PropsDictType = {
        "Count": (integer, False),
        "Interval": (integer, False),
        "IntervalUnit": (str, False),
    }


class ShareRule(AWSProperty):
    """
    `ShareRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-sharerule.html>`__
    """

    props: PropsDictType = {
        "TargetAccounts": ([str], False),
        "UnshareInterval": (integer, False),
        "UnshareIntervalUnit": (str, False),
    }


class Schedule(AWSProperty):
    """
    `Schedule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-schedule.html>`__
    """

    props: PropsDictType = {
        "ArchiveRule": (ArchiveRule, False),
        "CopyTags": (boolean, False),
        "CreateRule": (CreateRule, False),
        "CrossRegionCopyRules": ([CrossRegionCopyRule], False),
        "DeprecateRule": (DeprecateRule, False),
        "FastRestoreRule": (FastRestoreRule, False),
        "Name": (str, False),
        "RetainRule": (RetainRule, False),
        "ShareRules": ([ShareRule], False),
        "TagsToAdd": (validate_tags_or_list, False),
        "VariableTags": (Tags, False),
    }


class PolicyDetails(AWSProperty):
    """
    `PolicyDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-policydetails.html>`__
    """

    props: PropsDictType = {
        "Actions": ([Action], False),
        "CopyTags": (boolean, False),
        "CreateInterval": (integer, False),
        "CrossRegionCopyTargets": ([], False),
        "EventSource": (EventSource, False),
        "Exclusions": (Exclusions, False),
        "ExtendDeletion": (boolean, False),
        "Parameters": (Parameters, False),
        "PolicyLanguage": (str, False),
        "PolicyType": (str, False),
        "ResourceLocations": ([str], False),
        "ResourceType": (str, False),
        "ResourceTypes": ([str], False),
        "RetainInterval": (integer, False),
        "Schedules": ([Schedule], False),
        "TargetTags": (validate_tags_or_list, False),
    }


class LifecyclePolicy(AWSObject):
    """
    `LifecyclePolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-dlm-lifecyclepolicy.html>`__
    """

    resource_type = "AWS::DLM::LifecyclePolicy"

    props: PropsDictType = {
        "CopyTags": (boolean, False),
        "CreateInterval": (integer, False),
        "CrossRegionCopyTargets": ([], False),
        "DefaultPolicy": (str, False),
        "Description": (str, False),
        "Exclusions": (Exclusions, False),
        "ExecutionRoleArn": (str, False),
        "ExtendDeletion": (boolean, False),
        "PolicyDetails": (PolicyDetails, False),
        "RetainInterval": (integer, False),
        "State": (validate_state, False),
        "Tags": (validate_tags_or_list, False),
    }


class CrossRegionCopyTarget(AWSProperty):
    """
    `CrossRegionCopyTarget <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-dlm-lifecyclepolicy-crossregioncopytarget.html>`__
    """

    props: PropsDictType = {
        "TargetRegion": (str, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.


def validate_workgroup_state(workgroup_state):
    """
    Validate State for Workgroup
    Property: WorkGroup.State
    """

    VALID_WORKGROUP_STATE = ("ENABLED", "DISABLED")

    if workgroup_state not in VALID_WORKGROUP_STATE:
        raise ValueError(
            "Workgroup State must be one of: %s" % ", ".join(VALID_WORKGROUP_STATE)
        )
    return workgroup_state


def validate_encryptionoption(encryption_option):
    """
    Validate EncryptionOption for EncryptionConfiguration
    Property: EncryptionConfiguration.EncryptionOption
    """

    VALID_ENCRYPTIONCONFIGURATION_ENCRYPTIONOPTION = [
        "CSE_KMS",
        "SSE_KMS",
        "SSE_S3",
    ]

    if encryption_option not in VALID_ENCRYPTIONCONFIGURATION_ENCRYPTIONOPTION:
        raise ValueError(
            "EncryptionConfiguration EncryptionOption must be one of: %s"
            % ", ".join(VALID_ENCRYPTIONCONFIGURATION_ENCRYPTIONOPTION)  # NOQA
        )
    return encryption_option



import unittest

from troposphere.elasticloadbalancingv2 import (
    Action,
    FixedResponseConfig,
    RedirectConfig,
    TargetGroup,
)


class TestListenerActions(unittest.TestCase):
    def test_redirect_action(self):
        Action(
            Type="redirect",
            RedirectConfig=RedirectConfig(
                StatusCode="HTTP_301",
                Protocol="HTTPS",
                Host="api.troposphere.org",
                Path="redirect/#{path}",
            ),
        ).to_dict()

    def test_fixed_response_action(self):
        Action(
            Type="fixed-response",
            FixedResponseConfig=FixedResponseConfig(
                ContentType="text/plain",
                MessageBody="I am a fixed response",
                StatusCode="200",
            ),
        ).to_dict()

    def test_forward_action(self):
        Action(Type="forward", TargetGroupArn="").to_dict()

    def test_redirect_action_config_one_of(self):
        with self.assertRaises(ValueError):
            RedirectConfig(StatusCode="HTTP_200").to_dict()

    def test_fixed_response_config_one_of(self):
        with self.assertRaises(ValueError):
            FixedResponseConfig(
                ContentType="application/octet-stream",
            ).to_dict()

    def test_forward_action_requires_target_arn(self):
        with self.assertRaises(ValueError):
            Action(Type="forward").to_dict()

    def test_fixed_response_requires_fixed_response_config(self):
        with self.assertRaises(ValueError):
            Action(Type="fixed-response").to_dict()

    def test_redirect_action_requires_redirect_config(self):
        with self.assertRaises(ValueError):
            Action(Type="redirect").to_dict()

    def test_target_arn_only_forward(self):
        with self.assertRaises(ValueError):
            Action(Type="redirect", TargetGroupArn="").to_dict()

    def test_redirect_config_only_with_redirect(self):
        with self.assertRaises(ValueError):
            Action(
                Type="forward",
                RedirectConfig=RedirectConfig(
                    StatusCode="HTTP_301",
                ),
            ).to_dict()

    def test_fixed_response_config_only_with_fixed_response(self):
        with self.assertRaises(ValueError):
            Action(
                Type="forward",
                FixedResponseConfig=FixedResponseConfig(
                    ContentType="text/plain",
                ),
            ).to_dict()


class TestTargetGroup(unittest.TestCase):
    def test_lambda_targettype_rejects_properties(self):
        with self.assertRaises(ValueError) as valueError:
            TargetGroup(
                "targetGroup",
                TargetType="lambda",
                Port=433,
                Protocol="HTTPS",
                VpcId="unknown",
            ).to_dict()
        self.assertEqual(
            'TargetType of "lambda" in "TargetGroup" must not contain '
            + "definitions of 'Port', 'Protocol', 'VpcId'",
            str(valueError.exception),
        )

    def test_instance_targettype_requires_properties(self):
        with self.assertRaises(ValueError) as valueError:
            TargetGroup("targetGroup", TargetType="instance").to_dict()
        self.assertEqual(
            'TargetType of "instance" in "TargetGroup" requires '
            + "definitions of 'Port', 'Protocol', 'VpcId'",
            str(valueError.exception),
        )

    def test_ip_targettype_requires_properties(self):
        with self.assertRaises(ValueError) as valueError:
            TargetGroup("targetGroup", TargetType="ip").to_dict()
        self.assertEqual(
            'TargetType of "ip" in "TargetGroup" '
            + "requires definitions of 'Port', 'Protocol', 'VpcId'",
            str(valueError.exception),
        )

    def test_no_targettype_requires_properties(self):
        with self.assertRaises(ValueError) as valueError:
            TargetGroup("targetGroup").to_dict()
        self.assertEqual(
            'Omitting TargetType in "TargetGroup" '
            + "requires definitions of 'Port', 'Protocol', 'VpcId'",
            str(valueError.exception),
        )

    def test_invalid_targettype_is_rejected(self):
        with self.assertRaises(ValueError) as valueError:
            TargetGroup(
                "targetGroup",
                TargetType="invalid",
                Port=433,
                Protocol="HTTPS",
                VpcId="unknown",
            ).to_dict()
        self.assertEqual(
            'TargetGroup.TargetType must be one of: "alb, instance, ip, lambda"',
            str(valueError.exception),
        )


if __name__ == "__main__":
    unittest.main()



import unittest

from troposphere import Parameter, Ref
from troposphere.autoscaling import AutoScalingGroup
from troposphere.policies import (
    AutoScalingCreationPolicy,
    AutoScalingRollingUpdate,
    CreationPolicy,
    ResourceSignal,
    UpdatePolicy,
)


class TestCreationPolicy(unittest.TestCase):
    def test_invalid_pausetime(self):
        with self.assertRaises(ValueError):
            CreationPolicy(ResourceSignal=ResourceSignal(Count=2, Timeout="90"))

    def test_works(self):
        policy = CreationPolicy(ResourceSignal=ResourceSignal(Count=2, Timeout="PT10M"))
        self.assertEqual(policy.ResourceSignal.Count, 2)
        self.assertEqual(policy.ResourceSignal.Timeout, "PT10M")

    def test_json(self):
        policy = CreationPolicy(ResourceSignal=ResourceSignal(Count=2, Timeout="PT10M"))
        p = policy.to_dict()
        self.assertEqual(p["ResourceSignal"]["Count"], 2)
        self.assertEqual(p["ResourceSignal"]["Timeout"], "PT10M")

    def test_auto_scaling_creation_policy(self):
        policy = CreationPolicy(
            AutoScalingCreationPolicy=AutoScalingCreationPolicy(
                MinSuccessfulInstancesPercent=50,
            ),
            ResourceSignal=ResourceSignal(Count=2, Timeout="PT10M"),
        )
        self.assertEqual(
            policy.AutoScalingCreationPolicy.MinSuccessfulInstancesPercent, 50
        )

    def test_auto_scaling_creation_policy_json(self):
        policy = CreationPolicy(
            AutoScalingCreationPolicy=AutoScalingCreationPolicy(
                MinSuccessfulInstancesPercent=50,
            ),
            ResourceSignal=ResourceSignal(Count=2, Timeout="PT10M"),
        )
        p = policy.to_dict()
        self.assertEqual(
            p["AutoScalingCreationPolicy"]["MinSuccessfulInstancesPercent"], 50
        )


class TestUpdatePolicy(unittest.TestCase):
    def test_invalid_pausetime(self):
        with self.assertRaises(ValueError):
            UpdatePolicy(
                AutoScalingRollingUpdate=AutoScalingRollingUpdate(PauseTime="90")
            )

    def test_works(self):
        p = UpdatePolicy(
            AutoScalingRollingUpdate=AutoScalingRollingUpdate(
                MaxBatchSize=2,
                MinInstancesInService=1,
                PauseTime="PT90S",
                WaitOnResourceSignals=True,
            )
        )
        self.assertEqual(p.AutoScalingRollingUpdate.MaxBatchSize, 2)
        self.assertEqual(p.AutoScalingRollingUpdate.MinInstancesInService, 1)
        self.assertEqual(p.AutoScalingRollingUpdate.PauseTime, "PT90S")
        self.assertTrue(p.AutoScalingRollingUpdate.WaitOnResourceSignals)

    def test_mininstances(self):
        group = AutoScalingGroup(
            "mygroup",
            LaunchConfigurationName="I'm a test",
            MaxSize=1,
            MinSize=1,
            UpdatePolicy=UpdatePolicy(
                AutoScalingRollingUpdate=AutoScalingRollingUpdate(
                    PauseTime="PT1M5S", MinInstancesInService="1", MaxBatchSize="1"
                )
            ),
        )
        with self.assertRaises(ValueError):
            group.validate()

    def test_mininstances_maxsize_is_ref(self):
        paramMaxSize = Parameter("ParamMaxSize", Type="String")
        group = AutoScalingGroup(
            "mygroup",
            AvailabilityZones=["eu-west-1a", "eu-west-1b"],
            LaunchConfigurationName="I'm a test",
            MaxSize=Ref(paramMaxSize),
            MinSize="2",
            UpdatePolicy=UpdatePolicy(
                AutoScalingRollingUpdate=AutoScalingRollingUpdate(
                    PauseTime="PT1M5S", MinInstancesInService="2", MaxBatchSize="1"
                )
            ),
        )
        self.assertIsNone(group.validate())

    def test_mininstances_mininstancesinservice_is_ref(self):
        paramMinInstancesInService = Parameter(
            "ParamMinInstancesInService", Type="String"
        )
        group = AutoScalingGroup(
            "mygroup",
            AvailabilityZones=["eu-west-1a", "eu-west-1b"],
            LaunchConfigurationName="I'm a test",
            MaxSize="4",
            MinSize="2",
            UpdatePolicy=UpdatePolicy(
                AutoScalingRollingUpdate=AutoScalingRollingUpdate(
                    PauseTime="PT1M5S",
                    MinInstancesInService=Ref(paramMinInstancesInService),
                    MaxBatchSize="2",
                )
            ),
        )
        self.assertIsNone(group.validate())

    def test_json(self):
        p = UpdatePolicy(
            AutoScalingRollingUpdate=AutoScalingRollingUpdate(
                MaxBatchSize=2,
                MinInstancesInService=1,
                PauseTime="PT90S",
                WaitOnResourceSignals=True,
            )
        )
        p = p.to_dict()
        self.assertEqual(p["AutoScalingRollingUpdate"]["MaxBatchSize"], 2)
        self.assertEqual(p["AutoScalingRollingUpdate"]["MinInstancesInService"], 1)
        self.assertEqual(p["AutoScalingRollingUpdate"]["PauseTime"], "PT90S")
        self.assertTrue(p["AutoScalingRollingUpdate"]["WaitOnResourceSignals"])



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer


class EgressEndpoint(AWSProperty):
    """
    `EgressEndpoint <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-asset-egressendpoint.html>`__
    """

    props: PropsDictType = {
        "PackagingConfigurationId": (str, True),
        "Url": (str, True),
    }


class Asset(AWSObject):
    """
    `Asset <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackage-asset.html>`__
    """

    resource_type = "AWS::MediaPackage::Asset"

    props: PropsDictType = {
        "EgressEndpoints": ([EgressEndpoint], False),
        "Id": (str, True),
        "PackagingGroupId": (str, True),
        "ResourceId": (str, False),
        "SourceArn": (str, True),
        "SourceRoleArn": (str, True),
        "Tags": (Tags, False),
    }


class IngestEndpoint(AWSProperty):
    """
    `IngestEndpoint <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-channel-ingestendpoint.html>`__
    """

    props: PropsDictType = {
        "Id": (str, True),
        "Password": (str, True),
        "Url": (str, True),
        "Username": (str, True),
    }


class HlsIngest(AWSProperty):
    """
    `HlsIngest <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-channel-hlsingest.html>`__
    """

    props: PropsDictType = {
        "ingestEndpoints": ([IngestEndpoint], False),
    }


class LogConfiguration(AWSProperty):
    """
    `LogConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-packaginggroup-logconfiguration.html>`__
    """

    props: PropsDictType = {
        "LogGroupName": (str, False),
    }


class Channel(AWSObject):
    """
    `Channel <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackage-channel.html>`__
    """

    resource_type = "AWS::MediaPackage::Channel"

    props: PropsDictType = {
        "Description": (str, False),
        "EgressAccessLogs": (LogConfiguration, False),
        "HlsIngest": (HlsIngest, False),
        "Id": (str, True),
        "IngressAccessLogs": (LogConfiguration, False),
        "Tags": (Tags, False),
    }


class Authorization(AWSProperty):
    """
    `Authorization <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-packaginggroup-authorization.html>`__
    """

    props: PropsDictType = {
        "CdnIdentifierSecret": (str, True),
        "SecretsRoleArn": (str, True),
    }


class EncryptionContractConfiguration(AWSProperty):
    """
    `EncryptionContractConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-packagingconfiguration-encryptioncontractconfiguration.html>`__
    """

    props: PropsDictType = {
        "PresetSpeke20Audio": (str, True),
        "PresetSpeke20Video": (str, True),
    }


class OriginEndpointSpekeKeyProvider(AWSProperty):
    """
    `OriginEndpointSpekeKeyProvider <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-originendpoint-spekekeyprovider.html>`__
    """

    props: PropsDictType = {
        "CertificateArn": (str, False),
        "EncryptionContractConfiguration": (EncryptionContractConfiguration, False),
        "ResourceId": (str, True),
        "RoleArn": (str, True),
        "SystemIds": ([str], True),
        "Url": (str, True),
    }


class OriginEndpointCmafEncryption(AWSProperty):
    """
    `OriginEndpointCmafEncryption <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-originendpoint-cmafencryption.html>`__
    """

    props: PropsDictType = {
        "ConstantInitializationVector": (str, False),
        "EncryptionMethod": (str, False),
        "KeyRotationIntervalSeconds": (integer, False),
        "SpekeKeyProvider": (OriginEndpointSpekeKeyProvider, True),
    }


class OriginEndpointHlsManifest(AWSProperty):
    """
    `OriginEndpointHlsManifest <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-originendpoint-hlsmanifest.html>`__
    """

    props: PropsDictType = {
        "AdMarkers": (str, False),
        "AdTriggers": ([str], False),
        "AdsOnDeliveryRestrictions": (str, False),
        "Id": (str, True),
        "IncludeIframeOnlyStream": (boolean, False),
        "ManifestName": (str, False),
        "PlaylistType": (str, False),
        "PlaylistWindowSeconds": (integer, False),
        "ProgramDateTimeIntervalSeconds": (integer, False),
        "Url": (str, False),
    }


class StreamSelection(AWSProperty):
    """
    `StreamSelection <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-packagingconfiguration-streamselection.html>`__
    """

    props: PropsDictType = {
        "MaxVideoBitsPerSecond": (integer, False),
        "MinVideoBitsPerSecond": (integer, False),
        "StreamOrder": (str, False),
    }


class OriginEndpointCmafPackage(AWSProperty):
    """
    `OriginEndpointCmafPackage <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-originendpoint-cmafpackage.html>`__
    """

    props: PropsDictType = {
        "Encryption": (OriginEndpointCmafEncryption, False),
        "HlsManifests": ([OriginEndpointHlsManifest], False),
        "SegmentDurationSeconds": (integer, False),
        "SegmentPrefix": (str, False),
        "StreamSelection": (StreamSelection, False),
    }


class SpekeKeyProvider(AWSProperty):
    """
    `SpekeKeyProvider <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-packagingconfiguration-spekekeyprovider.html>`__
    """

    props: PropsDictType = {
        "EncryptionContractConfiguration": (EncryptionContractConfiguration, False),
        "RoleArn": (str, True),
        "SystemIds": ([str], True),
        "Url": (str, True),
    }


class OriginEndpointDashEncryption(AWSProperty):
    """
    `OriginEndpointDashEncryption <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-originendpoint-dashencryption.html>`__
    """

    props: PropsDictType = {
        "KeyRotationIntervalSeconds": (integer, False),
        "SpekeKeyProvider": (SpekeKeyProvider, True),
    }


class OriginEndpointDashPackage(AWSProperty):
    """
    `OriginEndpointDashPackage <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-originendpoint-dashpackage.html>`__
    """

    props: PropsDictType = {
        "AdTriggers": ([str], False),
        "AdsOnDeliveryRestrictions": (str, False),
        "Encryption": (OriginEndpointDashEncryption, False),
        "IncludeIframeOnlyStream": (boolean, False),
        "ManifestLayout": (str, False),
        "ManifestWindowSeconds": (integer, False),
        "MinBufferTimeSeconds": (integer, False),
        "MinUpdatePeriodSeconds": (integer, False),
        "PeriodTriggers": ([str], False),
        "Profile": (str, False),
        "SegmentDurationSeconds": (integer, False),
        "SegmentTemplateFormat": (str, False),
        "StreamSelection": (StreamSelection, False),
        "SuggestedPresentationDelaySeconds": (integer, False),
        "UtcTiming": (str, False),
        "UtcTimingUri": (str, False),
    }


class OriginEndpointHlsEncryption(AWSProperty):
    """
    `OriginEndpointHlsEncryption <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-originendpoint-hlsencryption.html>`__
    """

    props: PropsDictType = {
        "ConstantInitializationVector": (str, False),
        "EncryptionMethod": (str, False),
        "KeyRotationIntervalSeconds": (integer, False),
        "RepeatExtXKey": (boolean, False),
        "SpekeKeyProvider": (SpekeKeyProvider, True),
    }


class OriginEndpointHlsPackage(AWSProperty):
    """
    `OriginEndpointHlsPackage <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-originendpoint-hlspackage.html>`__
    """

    props: PropsDictType = {
        "AdMarkers": (str, False),
        "AdTriggers": ([str], False),
        "AdsOnDeliveryRestrictions": (str, False),
        "Encryption": (OriginEndpointHlsEncryption, False),
        "IncludeDvbSubtitles": (boolean, False),
        "IncludeIframeOnlyStream": (boolean, False),
        "PlaylistType": (str, False),
        "PlaylistWindowSeconds": (integer, False),
        "ProgramDateTimeIntervalSeconds": (integer, False),
        "SegmentDurationSeconds": (integer, False),
        "StreamSelection": (StreamSelection, False),
        "UseAudioRenditionGroup": (boolean, False),
    }


class MssEncryption(AWSProperty):
    """
    `MssEncryption <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-packagingconfiguration-mssencryption.html>`__
    """

    props: PropsDictType = {
        "SpekeKeyProvider": (SpekeKeyProvider, True),
    }


class OriginEndpointMssPackage(AWSProperty):
    """
    `OriginEndpointMssPackage <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-originendpoint-msspackage.html>`__
    """

    props: PropsDictType = {
        "Encryption": (MssEncryption, False),
        "ManifestWindowSeconds": (integer, False),
        "SegmentDurationSeconds": (integer, False),
        "StreamSelection": (StreamSelection, False),
    }


class OriginEndpoint(AWSObject):
    """
    `OriginEndpoint <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackage-originendpoint.html>`__
    """

    resource_type = "AWS::MediaPackage::OriginEndpoint"

    props: PropsDictType = {
        "Authorization": (Authorization, False),
        "ChannelId": (str, True),
        "CmafPackage": (OriginEndpointCmafPackage, False),
        "DashPackage": (OriginEndpointDashPackage, False),
        "Description": (str, False),
        "HlsPackage": (OriginEndpointHlsPackage, False),
        "Id": (str, True),
        "ManifestName": (str, False),
        "MssPackage": (OriginEndpointMssPackage, False),
        "Origination": (str, False),
        "StartoverWindowSeconds": (integer, False),
        "Tags": (Tags, False),
        "TimeDelaySeconds": (integer, False),
        "Whitelist": ([str], False),
    }


class CmafEncryption(AWSProperty):
    """
    `CmafEncryption <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-packagingconfiguration-cmafencryption.html>`__
    """

    props: PropsDictType = {
        "SpekeKeyProvider": (SpekeKeyProvider, True),
    }


class HlsManifest(AWSProperty):
    """
    `HlsManifest <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-packagingconfiguration-hlsmanifest.html>`__
    """

    props: PropsDictType = {
        "AdMarkers": (str, False),
        "IncludeIframeOnlyStream": (boolean, False),
        "ManifestName": (str, False),
        "ProgramDateTimeIntervalSeconds": (integer, False),
        "RepeatExtXKey": (boolean, False),
        "StreamSelection": (StreamSelection, False),
    }


class CmafPackage(AWSProperty):
    """
    `CmafPackage <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-packagingconfiguration-cmafpackage.html>`__
    """

    props: PropsDictType = {
        "Encryption": (CmafEncryption, False),
        "HlsManifests": ([HlsManifest], True),
        "IncludeEncoderConfigurationInSegments": (boolean, False),
        "SegmentDurationSeconds": (integer, False),
    }


class DashEncryption(AWSProperty):
    """
    `DashEncryption <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-packagingconfiguration-dashencryption.html>`__
    """

    props: PropsDictType = {
        "SpekeKeyProvider": (SpekeKeyProvider, True),
    }


class DashManifest(AWSProperty):
    """
    `DashManifest <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-packagingconfiguration-dashmanifest.html>`__
    """

    props: PropsDictType = {
        "ManifestLayout": (str, False),
        "ManifestName": (str, False),
        "MinBufferTimeSeconds": (integer, False),
        "Profile": (str, False),
        "ScteMarkersSource": (str, False),
        "StreamSelection": (StreamSelection, False),
    }


class DashPackage(AWSProperty):
    """
    `DashPackage <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-packagingconfiguration-dashpackage.html>`__
    """

    props: PropsDictType = {
        "DashManifests": ([DashManifest], True),
        "Encryption": (DashEncryption, False),
        "IncludeEncoderConfigurationInSegments": (boolean, False),
        "IncludeIframeOnlyStream": (boolean, False),
        "PeriodTriggers": ([str], False),
        "SegmentDurationSeconds": (integer, False),
        "SegmentTemplateFormat": (str, False),
    }


class HlsEncryption(AWSProperty):
    """
    `HlsEncryption <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-packagingconfiguration-hlsencryption.html>`__
    """

    props: PropsDictType = {
        "ConstantInitializationVector": (str, False),
        "EncryptionMethod": (str, False),
        "SpekeKeyProvider": (SpekeKeyProvider, True),
    }


class HlsPackage(AWSProperty):
    """
    `HlsPackage <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-packagingconfiguration-hlspackage.html>`__
    """

    props: PropsDictType = {
        "Encryption": (HlsEncryption, False),
        "HlsManifests": ([HlsManifest], True),
        "IncludeDvbSubtitles": (boolean, False),
        "SegmentDurationSeconds": (integer, False),
        "UseAudioRenditionGroup": (boolean, False),
    }


class MssManifest(AWSProperty):
    """
    `MssManifest <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-packagingconfiguration-mssmanifest.html>`__
    """

    props: PropsDictType = {
        "ManifestName": (str, False),
        "StreamSelection": (StreamSelection, False),
    }


class MssPackage(AWSProperty):
    """
    `MssPackage <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-mediapackage-packagingconfiguration-msspackage.html>`__
    """

    props: PropsDictType = {
        "Encryption": (MssEncryption, False),
        "MssManifests": ([MssManifest], True),
        "SegmentDurationSeconds": (integer, False),
    }


class PackagingConfiguration(AWSObject):
    """
    `PackagingConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackage-packagingconfiguration.html>`__
    """

    resource_type = "AWS::MediaPackage::PackagingConfiguration"

    props: PropsDictType = {
        "CmafPackage": (CmafPackage, False),
        "DashPackage": (DashPackage, False),
        "HlsPackage": (HlsPackage, False),
        "Id": (str, True),
        "MssPackage": (MssPackage, False),
        "PackagingGroupId": (str, True),
        "Tags": (Tags, False),
    }


class PackagingGroup(AWSObject):
    """
    `PackagingGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-mediapackage-packaginggroup.html>`__
    """

    resource_type = "AWS::MediaPackage::PackagingGroup"

    props: PropsDictType = {
        "Authorization": (Authorization, False),
        "EgressAccessLogs": (LogConfiguration, False),
        "Id": (str, True),
        "Tags": (Tags, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer


class Namespace(AWSObject):
    """
    `Namespace <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshiftserverless-namespace.html>`__
    """

    resource_type = "AWS::RedshiftServerless::Namespace"

    props: PropsDictType = {
        "AdminUserPassword": (str, False),
        "AdminUsername": (str, False),
        "DbName": (str, False),
        "DefaultIamRoleArn": (str, False),
        "FinalSnapshotName": (str, False),
        "FinalSnapshotRetentionPeriod": (integer, False),
        "IamRoles": ([str], False),
        "KmsKeyId": (str, False),
        "LogExports": ([str], False),
        "NamespaceName": (str, True),
        "Tags": (Tags, False),
    }


class ConfigParameter(AWSProperty):
    """
    `ConfigParameter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshiftserverless-workgroup-configparameter.html>`__
    """

    props: PropsDictType = {
        "ParameterKey": (str, False),
        "ParameterValue": (str, False),
    }


class NetworkInterface(AWSProperty):
    """
    `NetworkInterface <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshiftserverless-workgroup-networkinterface.html>`__
    """

    props: PropsDictType = {
        "AvailabilityZone": (str, False),
        "NetworkInterfaceId": (str, False),
        "PrivateIpAddress": (str, False),
        "SubnetId": (str, False),
    }


class VpcEndpoint(AWSProperty):
    """
    `VpcEndpoint <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshiftserverless-workgroup-vpcendpoint.html>`__
    """

    props: PropsDictType = {
        "NetworkInterfaces": ([NetworkInterface], False),
        "VpcEndpointId": (str, False),
        "VpcId": (str, False),
    }


class Endpoint(AWSProperty):
    """
    `Endpoint <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshiftserverless-workgroup-endpoint.html>`__
    """

    props: PropsDictType = {
        "Address": (str, False),
        "Port": (integer, False),
        "VpcEndpoints": ([VpcEndpoint], False),
    }


class WorkgroupProperty(AWSProperty):
    """
    `WorkgroupProperty <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshiftserverless-workgroup-workgroup.html>`__
    """

    props: PropsDictType = {
        "BaseCapacity": (integer, False),
        "ConfigParameters": ([ConfigParameter], False),
        "CreationDate": (str, False),
        "Endpoint": (Endpoint, False),
        "EnhancedVpcRouting": (boolean, False),
        "NamespaceName": (str, False),
        "PubliclyAccessible": (boolean, False),
        "SecurityGroupIds": ([str], False),
        "Status": (str, False),
        "SubnetIds": ([str], False),
        "WorkgroupArn": (str, False),
        "WorkgroupId": (str, False),
        "WorkgroupName": (str, False),
    }


class Workgroup(AWSObject):
    """
    `Workgroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-redshiftserverless-workgroup.html>`__
    """

    resource_type = "AWS::RedshiftServerless::Workgroup"

    props: PropsDictType = {
        "BaseCapacity": (integer, False),
        "ConfigParameters": ([ConfigParameter], False),
        "EnhancedVpcRouting": (boolean, False),
        "NamespaceName": (str, False),
        "Port": (integer, False),
        "PubliclyAccessible": (boolean, False),
        "SecurityGroupIds": ([str], False),
        "SubnetIds": ([str], False),
        "Tags": (Tags, False),
        "Workgroup": (WorkgroupProperty, False),
        "WorkgroupName": (str, True),
    }


class NamespaceProperty(AWSProperty):
    """
    `NamespaceProperty <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-redshiftserverless-namespace-namespace.html>`__
    """

    props: PropsDictType = {
        "AdminUsername": (str, False),
        "CreationDate": (str, False),
        "DbName": (str, False),
        "DefaultIamRoleArn": (str, False),
        "IamRoles": ([str], False),
        "KmsKeyId": (str, False),
        "LogExports": ([str], False),
        "NamespaceArn": (str, False),
        "NamespaceId": (str, False),
        "NamespaceName": (str, False),
        "Status": (str, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType
from .validators import boolean, double, integer


class NoteUpdate(AWSProperty):
    """
    `NoteUpdate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-noteupdate.html>`__
    """

    props: PropsDictType = {
        "Text": (str, True),
        "UpdatedBy": (dict, True),
    }


class RelatedFinding(AWSProperty):
    """
    `RelatedFinding <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-relatedfinding.html>`__
    """

    props: PropsDictType = {
        "Id": (dict, True),
        "ProductArn": (str, True),
    }


class SeverityUpdate(AWSProperty):
    """
    `SeverityUpdate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-severityupdate.html>`__
    """

    props: PropsDictType = {
        "Label": (str, False),
        "Normalized": (integer, False),
        "Product": (double, False),
    }


class WorkflowUpdate(AWSProperty):
    """
    `WorkflowUpdate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-workflowupdate.html>`__
    """

    props: PropsDictType = {
        "Status": (str, True),
    }


class AutomationRulesFindingFieldsUpdate(AWSProperty):
    """
    `AutomationRulesFindingFieldsUpdate <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-automationrulesfindingfieldsupdate.html>`__
    """

    props: PropsDictType = {
        "Confidence": (integer, False),
        "Criticality": (integer, False),
        "Note": (NoteUpdate, False),
        "RelatedFindings": ([RelatedFinding], False),
        "Severity": (SeverityUpdate, False),
        "Types": ([str], False),
        "UserDefinedFields": (dict, False),
        "VerificationState": (str, False),
        "Workflow": (WorkflowUpdate, False),
    }


class AutomationRulesAction(AWSProperty):
    """
    `AutomationRulesAction <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-automationrulesaction.html>`__
    """

    props: PropsDictType = {
        "FindingFieldsUpdate": (AutomationRulesFindingFieldsUpdate, True),
        "Type": (str, True),
    }


class DateRange(AWSProperty):
    """
    `DateRange <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-daterange.html>`__
    """

    props: PropsDictType = {
        "Unit": (str, True),
        "Value": (double, True),
    }


class DateFilter(AWSProperty):
    """
    `DateFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-datefilter.html>`__
    """

    props: PropsDictType = {
        "DateRange": (DateRange, False),
        "End": (str, False),
        "Start": (str, False),
    }


class MapFilter(AWSProperty):
    """
    `MapFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-mapfilter.html>`__
    """

    props: PropsDictType = {
        "Comparison": (str, True),
        "Key": (str, True),
        "Value": (str, True),
    }


class NumberFilter(AWSProperty):
    """
    `NumberFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-numberfilter.html>`__
    """

    props: PropsDictType = {
        "Eq": (double, False),
        "Gte": (double, False),
        "Lte": (double, False),
    }


class StringFilter(AWSProperty):
    """
    `StringFilter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-stringfilter.html>`__
    """

    props: PropsDictType = {
        "Comparison": (str, True),
        "Value": (str, True),
    }


class AutomationRulesFindingFilters(AWSProperty):
    """
    `AutomationRulesFindingFilters <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-automationrule-automationrulesfindingfilters.html>`__
    """

    props: PropsDictType = {
        "AwsAccountId": ([StringFilter], False),
        "CompanyName": ([StringFilter], False),
        "ComplianceAssociatedStandardsId": ([StringFilter], False),
        "ComplianceSecurityControlId": ([StringFilter], False),
        "ComplianceStatus": ([StringFilter], False),
        "Confidence": ([NumberFilter], False),
        "CreatedAt": ([DateFilter], False),
        "Criticality": ([NumberFilter], False),
        "Description": ([StringFilter], False),
        "FirstObservedAt": ([DateFilter], False),
        "GeneratorId": ([StringFilter], False),
        "Id": ([StringFilter], False),
        "LastObservedAt": ([DateFilter], False),
        "NoteText": ([StringFilter], False),
        "NoteUpdatedAt": ([DateFilter], False),
        "NoteUpdatedBy": ([StringFilter], False),
        "ProductArn": ([StringFilter], False),
        "ProductName": ([StringFilter], False),
        "RecordState": ([StringFilter], False),
        "RelatedFindingsId": ([StringFilter], False),
        "RelatedFindingsProductArn": ([StringFilter], False),
        "ResourceDetailsOther": ([MapFilter], False),
        "ResourceId": ([StringFilter], False),
        "ResourcePartition": ([StringFilter], False),
        "ResourceRegion": ([StringFilter], False),
        "ResourceTags": ([MapFilter], False),
        "ResourceType": ([StringFilter], False),
        "SeverityLabel": ([StringFilter], False),
        "SourceUrl": ([StringFilter], False),
        "Title": ([StringFilter], False),
        "Type": ([StringFilter], False),
        "UpdatedAt": ([DateFilter], False),
        "UserDefinedFields": ([MapFilter], False),
        "VerificationState": ([StringFilter], False),
        "WorkflowStatus": ([StringFilter], False),
    }


class AutomationRule(AWSObject):
    """
    `AutomationRule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securityhub-automationrule.html>`__
    """

    resource_type = "AWS::SecurityHub::AutomationRule"

    props: PropsDictType = {
        "Actions": ([AutomationRulesAction], False),
        "Criteria": (AutomationRulesFindingFilters, False),
        "Description": (str, False),
        "IsTerminal": (boolean, False),
        "RuleName": (str, False),
        "RuleOrder": (integer, False),
        "RuleStatus": (str, False),
        "Tags": (dict, False),
    }


class Hub(AWSObject):
    """
    `Hub <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securityhub-hub.html>`__
    """

    resource_type = "AWS::SecurityHub::Hub"

    props: PropsDictType = {
        "AutoEnableControls": (boolean, False),
        "ControlFindingGenerator": (str, False),
        "EnableDefaultStandards": (boolean, False),
        "Tags": (dict, False),
    }


class StandardsControl(AWSProperty):
    """
    `StandardsControl <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-securityhub-standard-standardscontrol.html>`__
    """

    props: PropsDictType = {
        "Reason": (str, False),
        "StandardsControlArn": (str, True),
    }


class Standard(AWSObject):
    """
    `Standard <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-securityhub-standard.html>`__
    """

    resource_type = "AWS::SecurityHub::Standard"

    props: PropsDictType = {
        "DisabledStandardsControls": ([StandardsControl], False),
        "StandardsArn": (str, True),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer


class BatchScramSecret(AWSObject):
    """
    `BatchScramSecret <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-msk-batchscramsecret.html>`__
    """

    resource_type = "AWS::MSK::BatchScramSecret"

    props: PropsDictType = {
        "ClusterArn": (str, True),
        "SecretArnList": ([str], False),
    }


class PublicAccess(AWSProperty):
    """
    `PublicAccess <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-publicaccess.html>`__
    """

    props: PropsDictType = {
        "Type": (str, False),
    }


class VpcConnectivityIam(AWSProperty):
    """
    `VpcConnectivityIam <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-vpcconnectivityiam.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, True),
    }


class VpcConnectivityScram(AWSProperty):
    """
    `VpcConnectivityScram <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-vpcconnectivityscram.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, True),
    }


class VpcConnectivitySasl(AWSProperty):
    """
    `VpcConnectivitySasl <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-vpcconnectivitysasl.html>`__
    """

    props: PropsDictType = {
        "Iam": (VpcConnectivityIam, False),
        "Scram": (VpcConnectivityScram, False),
    }


class VpcConnectivityTls(AWSProperty):
    """
    `VpcConnectivityTls <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-vpcconnectivitytls.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, True),
    }


class VpcConnectivityClientAuthentication(AWSProperty):
    """
    `VpcConnectivityClientAuthentication <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-vpcconnectivityclientauthentication.html>`__
    """

    props: PropsDictType = {
        "Sasl": (VpcConnectivitySasl, False),
        "Tls": (VpcConnectivityTls, False),
    }


class VpcConnectivity(AWSProperty):
    """
    `VpcConnectivity <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-vpcconnectivity.html>`__
    """

    props: PropsDictType = {
        "ClientAuthentication": (VpcConnectivityClientAuthentication, False),
    }


class ConnectivityInfo(AWSProperty):
    """
    `ConnectivityInfo <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-connectivityinfo.html>`__
    """

    props: PropsDictType = {
        "PublicAccess": (PublicAccess, False),
        "VpcConnectivity": (VpcConnectivity, False),
    }


class ProvisionedThroughput(AWSProperty):
    """
    `ProvisionedThroughput <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-provisionedthroughput.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, False),
        "VolumeThroughput": (integer, False),
    }


class EBSStorageInfo(AWSProperty):
    """
    `EBSStorageInfo <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-ebsstorageinfo.html>`__
    """

    props: PropsDictType = {
        "ProvisionedThroughput": (ProvisionedThroughput, False),
        "VolumeSize": (integer, False),
    }


class StorageInfo(AWSProperty):
    """
    `StorageInfo <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-storageinfo.html>`__
    """

    props: PropsDictType = {
        "EBSStorageInfo": (EBSStorageInfo, False),
    }


class BrokerNodeGroupInfo(AWSProperty):
    """
    `BrokerNodeGroupInfo <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-brokernodegroupinfo.html>`__
    """

    props: PropsDictType = {
        "BrokerAZDistribution": (str, False),
        "ClientSubnets": ([str], True),
        "ConnectivityInfo": (ConnectivityInfo, False),
        "InstanceType": (str, True),
        "SecurityGroups": ([str], False),
        "StorageInfo": (StorageInfo, False),
    }


class Iam(AWSProperty):
    """
    `Iam <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-serverlesscluster-iam.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, True),
    }


class Scram(AWSProperty):
    """
    `Scram <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-scram.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, True),
    }


class Sasl(AWSProperty):
    """
    `Sasl <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-sasl.html>`__
    """

    props: PropsDictType = {
        "Iam": (Iam, False),
        "Scram": (Scram, False),
    }


class Tls(AWSProperty):
    """
    `Tls <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-tls.html>`__
    """

    props: PropsDictType = {
        "CertificateAuthorityArnList": ([str], False),
        "Enabled": (boolean, False),
    }


class Unauthenticated(AWSProperty):
    """
    `Unauthenticated <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-unauthenticated.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, True),
    }


class ClientAuthentication(AWSProperty):
    """
    `ClientAuthentication <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-clientauthentication.html>`__
    """

    props: PropsDictType = {
        "Sasl": (Sasl, False),
        "Tls": (Tls, False),
        "Unauthenticated": (Unauthenticated, False),
    }


class ConfigurationInfo(AWSProperty):
    """
    `ConfigurationInfo <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-configurationinfo.html>`__
    """

    props: PropsDictType = {
        "Arn": (str, True),
        "Revision": (integer, True),
    }


class EncryptionAtRest(AWSProperty):
    """
    `EncryptionAtRest <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-encryptionatrest.html>`__
    """

    props: PropsDictType = {
        "DataVolumeKMSKeyId": (str, True),
    }


class EncryptionInTransit(AWSProperty):
    """
    `EncryptionInTransit <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-encryptionintransit.html>`__
    """

    props: PropsDictType = {
        "ClientBroker": (str, False),
        "InCluster": (boolean, False),
    }


class EncryptionInfo(AWSProperty):
    """
    `EncryptionInfo <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-encryptioninfo.html>`__
    """

    props: PropsDictType = {
        "EncryptionAtRest": (EncryptionAtRest, False),
        "EncryptionInTransit": (EncryptionInTransit, False),
    }


class CloudWatchLogs(AWSProperty):
    """
    `CloudWatchLogs <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-cloudwatchlogs.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, True),
        "LogGroup": (str, False),
    }


class Firehose(AWSProperty):
    """
    `Firehose <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-firehose.html>`__
    """

    props: PropsDictType = {
        "DeliveryStream": (str, False),
        "Enabled": (boolean, True),
    }


class S3(AWSProperty):
    """
    `S3 <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-s3.html>`__
    """

    props: PropsDictType = {
        "Bucket": (str, False),
        "Enabled": (boolean, True),
        "Prefix": (str, False),
    }


class BrokerLogs(AWSProperty):
    """
    `BrokerLogs <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-brokerlogs.html>`__
    """

    props: PropsDictType = {
        "CloudWatchLogs": (CloudWatchLogs, False),
        "Firehose": (Firehose, False),
        "S3": (S3, False),
    }


class LoggingInfo(AWSProperty):
    """
    `LoggingInfo <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-logginginfo.html>`__
    """

    props: PropsDictType = {
        "BrokerLogs": (BrokerLogs, True),
    }


class JmxExporter(AWSProperty):
    """
    `JmxExporter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-jmxexporter.html>`__
    """

    props: PropsDictType = {
        "EnabledInBroker": (boolean, True),
    }


class NodeExporter(AWSProperty):
    """
    `NodeExporter <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-nodeexporter.html>`__
    """

    props: PropsDictType = {
        "EnabledInBroker": (boolean, True),
    }


class Prometheus(AWSProperty):
    """
    `Prometheus <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-prometheus.html>`__
    """

    props: PropsDictType = {
        "JmxExporter": (JmxExporter, False),
        "NodeExporter": (NodeExporter, False),
    }


class OpenMonitoring(AWSProperty):
    """
    `OpenMonitoring <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-cluster-openmonitoring.html>`__
    """

    props: PropsDictType = {
        "Prometheus": (Prometheus, True),
    }


class Cluster(AWSObject):
    """
    `Cluster <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-msk-cluster.html>`__
    """

    resource_type = "AWS::MSK::Cluster"

    props: PropsDictType = {
        "BrokerNodeGroupInfo": (BrokerNodeGroupInfo, True),
        "ClientAuthentication": (ClientAuthentication, False),
        "ClusterName": (str, True),
        "ConfigurationInfo": (ConfigurationInfo, False),
        "CurrentVersion": (str, False),
        "EncryptionInfo": (EncryptionInfo, False),
        "EnhancedMonitoring": (str, False),
        "KafkaVersion": (str, True),
        "LoggingInfo": (LoggingInfo, False),
        "NumberOfBrokerNodes": (integer, True),
        "OpenMonitoring": (OpenMonitoring, False),
        "StorageMode": (str, False),
        "Tags": (dict, False),
    }


class ClusterPolicy(AWSObject):
    """
    `ClusterPolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-msk-clusterpolicy.html>`__
    """

    resource_type = "AWS::MSK::ClusterPolicy"

    props: PropsDictType = {
        "ClusterArn": (str, True),
        "Policy": (dict, True),
    }


class LatestRevision(AWSProperty):
    """
    `LatestRevision <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-configuration-latestrevision.html>`__
    """

    props: PropsDictType = {
        "CreationTime": (str, False),
        "Description": (str, False),
        "Revision": (integer, False),
    }


class Configuration(AWSObject):
    """
    `Configuration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-msk-configuration.html>`__
    """

    resource_type = "AWS::MSK::Configuration"

    props: PropsDictType = {
        "Description": (str, False),
        "KafkaVersionsList": ([str], False),
        "LatestRevision": (LatestRevision, False),
        "Name": (str, True),
        "ServerProperties": (str, True),
    }


class AmazonMskCluster(AWSProperty):
    """
    `AmazonMskCluster <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-replicator-amazonmskcluster.html>`__
    """

    props: PropsDictType = {
        "MskClusterArn": (str, True),
    }


class KafkaClusterClientVpcConfig(AWSProperty):
    """
    `KafkaClusterClientVpcConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-replicator-kafkaclusterclientvpcconfig.html>`__
    """

    props: PropsDictType = {
        "SecurityGroupIds": ([str], False),
        "SubnetIds": ([str], True),
    }


class KafkaCluster(AWSProperty):
    """
    `KafkaCluster <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-replicator-kafkacluster.html>`__
    """

    props: PropsDictType = {
        "AmazonMskCluster": (AmazonMskCluster, True),
        "VpcConfig": (KafkaClusterClientVpcConfig, True),
    }


class ConsumerGroupReplication(AWSProperty):
    """
    `ConsumerGroupReplication <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-replicator-consumergroupreplication.html>`__
    """

    props: PropsDictType = {
        "ConsumerGroupsToExclude": ([str], False),
        "ConsumerGroupsToReplicate": ([str], True),
        "DetectAndCopyNewConsumerGroups": (boolean, False),
        "SynchroniseConsumerGroupOffsets": (boolean, False),
    }


class TopicReplication(AWSProperty):
    """
    `TopicReplication <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-replicator-topicreplication.html>`__
    """

    props: PropsDictType = {
        "CopyAccessControlListsForTopics": (boolean, False),
        "CopyTopicConfigurations": (boolean, False),
        "DetectAndCopyNewTopics": (boolean, False),
        "TopicsToExclude": ([str], False),
        "TopicsToReplicate": ([str], True),
    }


class ReplicationInfo(AWSProperty):
    """
    `ReplicationInfo <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-replicator-replicationinfo.html>`__
    """

    props: PropsDictType = {
        "ConsumerGroupReplication": (ConsumerGroupReplication, True),
        "SourceKafkaClusterArn": (str, True),
        "TargetCompressionType": (str, True),
        "TargetKafkaClusterArn": (str, True),
        "TopicReplication": (TopicReplication, True),
    }


class Replicator(AWSObject):
    """
    `Replicator <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-msk-replicator.html>`__
    """

    resource_type = "AWS::MSK::Replicator"

    props: PropsDictType = {
        "CurrentVersion": (str, False),
        "Description": (str, False),
        "KafkaClusters": ([KafkaCluster], True),
        "ReplicationInfoList": ([ReplicationInfo], True),
        "ReplicatorName": (str, True),
        "ServiceExecutionRoleArn": (str, True),
        "Tags": (Tags, False),
    }


class VpcConfig(AWSProperty):
    """
    `VpcConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-msk-serverlesscluster-vpcconfig.html>`__
    """

    props: PropsDictType = {
        "SecurityGroups": ([str], False),
        "SubnetIds": ([str], True),
    }


class ServerlessCluster(AWSObject):
    """
    `ServerlessCluster <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-msk-serverlesscluster.html>`__
    """

    resource_type = "AWS::MSK::ServerlessCluster"

    props: PropsDictType = {
        "ClientAuthentication": (ClientAuthentication, True),
        "ClusterName": (str, True),
        "Tags": (dict, False),
        "VpcConfigs": ([VpcConfig], True),
    }


class VpcConnection(AWSObject):
    """
    `VpcConnection <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-msk-vpcconnection.html>`__
    """

    resource_type = "AWS::MSK::VpcConnection"

    props: PropsDictType = {
        "Authentication": (str, True),
        "ClientSubnets": ([str], True),
        "SecurityGroups": ([str], True),
        "Tags": (dict, False),
        "TargetClusterArn": (str, True),
        "VpcId": (str, True),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.

import re

from .. import AWSProperty
from ..compat import validate_policytype
from ..type_defs.compat import Final
from . import exactly_one, integer_range, network_port, tags_or_list

PERMISSION_INSTANCE_ATTACH: Final = "INSTANCE-ATTACH"
PERMISSION_EIP_ASSOCIATE: Final = "EIP-ASSOCIATE"

NO_DEVICE: Final = {}


def Ipv6Addresses(ipv6_address):
    """
    Export:
    """
    from ..ec2 import InstanceIpv6Address

    return InstanceIpv6Address(Ipv6Address=ipv6_address)


class Tag(AWSProperty):
    """
    Export:
    """

    props = {
        "Key": (str, True),
        "Value": (str, True),
    }

    def __init__(self, key=None, value=None, **kwargs):
        # provided for backward compatibility
        if key is not None:
            kwargs["Key"] = key
        if value is not None:
            kwargs["Value"] = value
        super().__init__(**kwargs)


def validate_int_to_str(x):
    """
    Backward compatibility - field was int and now str.
    Property: NetworkInterfaceProperty.DeviceIndex
    Property: NetworkInterfaceAttachment.DeviceIndex
    """

    if isinstance(x, int):
        return str(x)
    if isinstance(x, str):
        return str(int(x))

    raise TypeError(f"Value {x} of type {type(x)} must be either int or str")


def policytypes(policy):
    """
    Property: VPCEndpoint.PolicyDocument
    """
    return validate_policytype(policy)


def validate_networkaclentry_rulenumber(x):
    """
    Property: NetworkAclEntry.RuleNumber
    """
    return integer_range(1, 32766)(x)


def validate_network_port(x):
    """
    Property: NetworkAclEntry.Protocol
    Property: PortRange.From
    Property: PortRange.To
    Property: SecurityGroupRule.FromPort
    Property: SecurityGroupRule.ToPort
    Property: SecurityGroupEgress.FromPort
    Property: SecurityGroupEgress.ToPort
    Property: SecurityGroupIngress.FromPort
    Property: SecurityGroupIngress.ToPort
    """
    return network_port(x)


def validate_tags_or_list(x):
    """
    Property: TagSpecifications.Tags
    Property: CustomerGateway.Tags
    Property: DHCPOptions.Tags
    Property: Instance.Tags
    Property: InternetGateway.Tags
    Property: LocalGatewayRouteTableVPCAssociation.Tags
    Property: NatGateway.Tags
    Property: NetworkAcl.Tags
    Property: NetworkInterface.Tags
    Property: RouteTable.Tags
    Property: SecurityGroup.Tags
    Property: SpotFleetTagSpecification.Tags
    Property: Subnet.Tags
    Property: TransitGateway.Tags
    Property: TransitGatewayAttachment.Tags
    Property: TransitGatewayRouteTable.Tags
    Property: VPC.Tags
    Property: VPCPeeringConnection.Tags
    Property: VPNConnection.Tags
    Property: VPNGateway.Tags
    Property: Volume.Tags
    Property: VPNGateway.Tags
    Property: VPNGateway.Tags
    """
    return tags_or_list(x)


def instance_tenancy(value):
    """
    Property: VPC.InstanceTenancy
    """
    valid = ["default", "dedicated"]
    if value not in valid:
        raise ValueError("InstanceTenancy needs to be one of %r" % valid)
    return value


def check_ports(props):
    # IpProtocol is a required field but not all values allowed require
    # ToPort and FromPort. The ones that don't need these ports are:
    ports_optional = [
        "-1",  # all protocols
        "58",  # ICMPv6
    ]
    proto = props["IpProtocol"]

    if proto not in ports_optional:
        if not ("ToPort" in props and "FromPort" in props):
            raise ValueError("ToPort/FromPort must be specified for proto %s" % proto)


def validate_elasticinferenceaccelerator_type(elasticinferenceaccelerator_type):
    """
    Validate ElasticInferenceAccelerator for Instance
    Property: ElasticInferenceAccelerator.Type
    Property: LaunchTemplateElasticInferenceAccelerator.Type
    """

    VALID_ELASTICINFERENCEACCELERATOR_TYPES = (
        "eia1.medium",
        "eia1.large",
        "eia1.xlarge",
    )
    if elasticinferenceaccelerator_type not in VALID_ELASTICINFERENCEACCELERATOR_TYPES:
        raise ValueError(
            "Elastic Inference Accelerator Type must be one of: %s"
            % ", ".join(VALID_ELASTICINFERENCEACCELERATOR_TYPES)
        )
    return elasticinferenceaccelerator_type


def validate_clientvpnendpoint_selfserviceportal(value):
    """
    Validate SelfServicePortal for ClientVpnEndpoint.
    Property: ClientVpnEndpoint.SelfServicePortal
    """

    VALID_CLIENTVPNENDPOINT_SELFSERVICEPORTAL = ("disabled", "enabled")

    if value not in VALID_CLIENTVPNENDPOINT_SELFSERVICEPORTAL:
        raise ValueError(
            "ClientVpnEndpoint.SelfServicePortal must be one of: {}".format(
                ", ".join(VALID_CLIENTVPNENDPOINT_SELFSERVICEPORTAL)
            )
        )
    return value


def validate_clientvpnendpoint_vpnport(vpnport):
    """
    Validate VpnPort for ClientVpnEndpoint
    Property: ClientVpnEndpoint.VpnPort
    """

    VALID_CLIENTVPNENDPOINT_VPNPORT = (443, 1194)
    if vpnport not in VALID_CLIENTVPNENDPOINT_VPNPORT:
        raise ValueError(
            "ClientVpnEndpoint VpnPort must be one of: %s"
            % ", ".join(VALID_CLIENTVPNENDPOINT_VPNPORT)
        )
    return vpnport


def vpn_pre_shared_key(key):
    """
    Property: VpnTunnelOptionsSpecification.PreSharedKey
    """
    pre_shared_key_match_re = re.compile(r"^(?!0)([A-Za-z0-9]|\_|\.){8,64}$")
    if not pre_shared_key_match_re.match(key):
        raise ValueError(
            "%s is not a valid key."
            " Allowed characters are alphanumeric characters and ._. Must"
            " be between 8 and 64 characters in length and cannot"
            " start with zero (0)." % key
        )
    return key


def vpn_tunnel_inside_cidr(cidr):
    """
    Property: VpnTunnelOptionsSpecification.TunnelInsideCidr
    """
    reserved_cidrs = [
        "169.254.0.0/30",
        "169.254.1.0/30",
        "169.254.2.0/30",
        "169.254.3.0/30",
        "169.254.4.0/30",
        "169.254.5.0/30",
        "169.254.169.252/30",
    ]
    cidr_match_re = re.compile(
        r"^169\.254\.(?:25[0-5]|2[0-4]\d|[01]?\d\d?)"
        r"\.(?:25[0-5]|2[0-4]\d|[01]?\d\d?)\/30$"
    )
    if cidr in reserved_cidrs:
        raise ValueError(
            'The following CIDR blocks are reserved and cannot be used: "%s"'
            % (", ".join(reserved_cidrs))
        )
    elif not cidr_match_re.match(cidr):
        raise ValueError(
            "%s is not a valid CIDR."
            " A size /30 CIDR block from the 169.254.0.0/16 must be specified." % cidr
        )
    return cidr


def vpc_endpoint_type(endpoint_type):
    """
    Property: VPCEndpoint.VpcEndpointType
    """
    valid_types = ["Interface", "Gateway", "GatewayLoadBalancer"]
    if endpoint_type not in valid_types:
        raise ValueError(
            'VpcEndpointType must be one of: "%s"' % (", ".join(valid_types))
        )
    return endpoint_type


def validate_network_acl_entry(self):
    """
    Class: NetworkAclEntry
    """
    conds = [
        "CidrBlock",
        "Ipv6CidrBlock",
    ]
    exactly_one(self.__class__.__name__, self.properties, conds)


def validate_route(self):
    """
    Class: Route
    """
    cidr_conds = [
        "DestinationCidrBlock",
        "DestinationIpv6CidrBlock",
    ]
    gateway_conds = [
        "CarrierGatewayId",
        "EgressOnlyInternetGatewayId",
        "GatewayId",
        "InstanceId",
        "LocalGatewayId",
        "NatGatewayId",
        "NetworkInterfaceId",
        "TransitGatewayId",
        "VpcEndpointId",
        "VpcPeeringConnectionId",
    ]
    exactly_one(self.__class__.__name__, self.properties, cidr_conds)
    exactly_one(self.__class__.__name__, self.properties, gateway_conds)


def validate_security_group_egress(self):
    """
    Class: SecurityGroupEgress
    """
    conds = [
        "CidrIp",
        "CidrIpv6",
        "DestinationPrefixListId",
        "DestinationSecurityGroupId",
    ]
    exactly_one(self.__class__.__name__, self.properties, conds)
    check_ports(self.properties)


def validate_security_group_ingress(self):
    """
    Class: SecurityGroupIngress
    """
    conds = [
        "CidrIp",
        "CidrIpv6",
        "SourcePrefixListId",
        "SourceSecurityGroupName",
        "SourceSecurityGroupId",
    ]
    exactly_one(self.__class__.__name__, self.properties, conds)
    check_ports(self.properties)


def validate_spot_fleet_request_config_data(self):
    """
    Class: SpotFleetRequestConfigData
    """
    conds = ["LaunchSpecifications", "LaunchTemplateConfigs"]
    exactly_one(self.__class__.__name__, self.properties, conds)


def validate_subnet(self):
    """
    Class: Subnet
    """
    if self.properties.get("AssignIpv6AddressOnCreation"):
        if "Ipv6CidrBlock" not in self.properties:
            raise ValueError(
                "If AssignIpv6AddressOnCreation is set to True, "
                "Ipv6CidrBlock must be present"
            )


def validate_vpn_connection(self):
    """
    Class: VPNConnection
    """
    conds = [
        "VpnGatewayId",
        "TransitGatewayId",
    ]
    exactly_one(self.__class__.__name__, self.properties, conds)


def validate_placement_strategy(strategy):
    """
    Validate PlacementGroup Strategy
    Property: PlacementGroup.Strategy
    """

    VALID_PLACEMENT_STRATEGIES = ["cluster", "partition", "spread"]

    if strategy not in VALID_PLACEMENT_STRATEGIES:
        raise ValueError(
            "PlacementGroup Strategy must be one of: %s"
            % ", ".join(VALID_PLACEMENT_STRATEGIES)
        )
    return strategy


def validate_placement_spread_level(spread_level):
    """
    Validate PlacementGroup SpreadLevel
    Property: PlacementGroup.SpreadLevel
    """

    VALID_PLACEMENT_SPREAD_LEVEL = [
        "host",
        "rack",
    ]

    if spread_level not in VALID_PLACEMENT_SPREAD_LEVEL:
        raise ValueError(
            "PlacementGroup SpreadLevel must be one of: %s"
            % ", ".join(VALID_PLACEMENT_SPREAD_LEVEL)
        )
    return spread_level



# Converted from VPC_With_VPN_Connection.template located at:
# http://aws.amazon.com/cloudformation/aws-cloudformation-templates/

from troposphere import Join, Output, Parameter, Ref, Tags, Template
from troposphere.ec2 import (
    VPC,
    CustomerGateway,
    NetworkAcl,
    NetworkAclEntry,
    PortRange,
    Route,
    RouteTable,
    Subnet,
    SubnetNetworkAclAssociation,
    SubnetRouteTableAssociation,
    VPCGatewayAttachment,
    VPNConnection,
    VPNConnectionRoute,
    VPNGateway,
)

t = Template()

t.set_version("2010-09-09")

t.set_description(
    """\
AWS CloudFormation Sample Template VPC_With_VPN_Connection.template: \
Sample template showing how to create a private subnet with a VPN connection \
using static routing to an existing VPN endpoint. NOTE: The VPNConnection \
created will define the configuration you need yonk the tunnels to your VPN \
endpoint - you can get the VPN Gateway configuration from the AWS Management \
console. You will be billed for the AWS resources used if you create a stack \
from this template."""
)
VPNAddress = t.add_parameter(
    Parameter(
        "VPNAddress",
        Type="String",
        Description="IP Address of your VPN device",
        MinLength="7",
        AllowedPattern=r"(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})",
        MaxLength="15",
        ConstraintDescription="must be a valid IP address of the form x.x.x.x",
    )
)

OnPremiseCIDR = t.add_parameter(
    Parameter(
        "OnPremiseCIDR",
        ConstraintDescription=("must be a valid IP CIDR range of the form x.x.x.x/x."),
        Description="IP Address range for your existing infrastructure",
        Default="10.0.0.0/16",
        MinLength="9",
        AllowedPattern=r"(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})/(\d{1,2})",
        MaxLength="18",
        Type="String",
    )
)

VPCCIDR = t.add_parameter(
    Parameter(
        "VPCCIDR",
        ConstraintDescription=("must be a valid IP CIDR range of the form x.x.x.x/x."),
        Description="IP Address range for the VPN connected VPC",
        Default="10.1.0.0/16",
        MinLength="9",
        AllowedPattern=r"(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})/(\d{1,2})",
        MaxLength="18",
        Type="String",
    )
)

SubnetCIDR = t.add_parameter(
    Parameter(
        "SubnetCIDR",
        ConstraintDescription=("must be a valid IP CIDR range of the form x.x.x.x/x."),
        Description="IP Address range for the VPN connected Subnet",
        Default="10.1.0.0/24",
        MinLength="9",
        AllowedPattern=r"(\d{1,3})\.(\d{1,3})\.(\d{1,3})\.(\d{1,3})/(\d{1,2})",
        MaxLength="18",
        Type="String",
    )
)

PrivateNetworkAcl = t.add_resource(
    NetworkAcl(
        "PrivateNetworkAcl",
        VpcId=Ref("VPC"),
        Tags=Tags(
            Application=Ref("AWS::StackName"),
            Network="Private",
        ),
    )
)

PrivateRoute = t.add_resource(
    Route(
        "PrivateRoute",
        GatewayId=Ref("VPNGateway"),
        DestinationCidrBlock="0.0.0.0/0",
        RouteTableId=Ref("PrivateRouteTable"),
    )
)

VPNGatewayAttachment = t.add_resource(
    VPCGatewayAttachment(
        "VPNGatewayAttachment",
        VpcId=Ref("VPC"),
        VpnGatewayId=Ref("VPNGateway"),
    )
)

PrivateSubnetRouteTableAssociation = t.add_resource(
    SubnetRouteTableAssociation(
        "PrivateSubnetRouteTableAssociation",
        SubnetId=Ref("PrivateSubnet"),
        RouteTableId=Ref("PrivateRouteTable"),
    )
)

PrivateSubnet = t.add_resource(
    Subnet(
        "PrivateSubnet",
        VpcId=Ref("VPC"),
        CidrBlock=Ref(SubnetCIDR),
        Tags=Tags(
            Application=Ref("AWS::StackName"),
            Network="VPN Connected Subnet",
        ),
    )
)

CustomerGatewayResource = t.add_resource(
    CustomerGateway(
        "CustomerGateway",
        BgpAsn="65000",
        IpAddress=Ref(VPNAddress),
        Type="ipsec.1",
        Tags=Tags(
            Application=Ref("AWS::StackName"),
            VPN=Join("", ["Gateway to ", Ref(VPNAddress)]),
        ),
    )
)

VPNConnectionRouteResource = t.add_resource(
    VPNConnectionRoute(
        "VPNConnectionRoute",
        VpnConnectionId=Ref("VPNConnection"),
        DestinationCidrBlock=Ref(OnPremiseCIDR),
    )
)

PrivateRouteTable = t.add_resource(
    RouteTable(
        "PrivateRouteTable",
        VpcId=Ref("VPC"),
        Tags=Tags(
            Application=Ref("AWS::StackName"),
            Network="VPN Connected Subnet",
        ),
    )
)

VPCResource = t.add_resource(
    VPC(
        "VPC",
        EnableDnsSupport="true",
        CidrBlock=Ref(VPCCIDR),
        EnableDnsHostnames="true",
        Tags=Tags(
            Application=Ref("AWS::StackName"),
            Network="VPN Connected VPC",
        ),
    )
)

OutBoundPrivateNetworkAclEntry = t.add_resource(
    NetworkAclEntry(
        "OutBoundPrivateNetworkAclEntry",
        NetworkAclId=Ref(PrivateNetworkAcl),
        RuleNumber="100",
        Protocol="6",
        PortRange=PortRange(To="65535", From="0"),
        Egress="true",
        RuleAction="allow",
        CidrBlock="0.0.0.0/0",
    )
)

VPNGatewayResource = t.add_resource(
    VPNGateway(
        "VPNGateway",
        Type="ipsec.1",
        Tags=Tags(
            Application=Ref("AWS::StackName"),
        ),
    )
)

PrivateSubnetNetworkAclAssociation = t.add_resource(
    SubnetNetworkAclAssociation(
        "PrivateSubnetNetworkAclAssociation",
        SubnetId=Ref(PrivateSubnet),
        NetworkAclId=Ref(PrivateNetworkAcl),
    )
)

t.add_resource(
    VPNConnection(
        "VPNConnection",
        CustomerGatewayId=Ref(CustomerGatewayResource),
        StaticRoutesOnly="true",
        Type="ipsec.1",
        VpnGatewayId=Ref(VPNGatewayResource),
    )
)

InboundPrivateNetworkAclEntry = t.add_resource(
    NetworkAclEntry(
        "InboundPrivateNetworkAclEntry",
        NetworkAclId=Ref(PrivateNetworkAcl),
        RuleNumber="100",
        Protocol="6",
        PortRange=PortRange(To="65535", From="0"),
        Egress="false",
        RuleAction="allow",
        CidrBlock="0.0.0.0/0",
    )
)

PrivateSubnet = t.add_output(
    Output(
        "PrivateSubnet",
        Description="SubnetId of the VPN connected subnet",
        Value=Ref(PrivateSubnet),
    )
)

VPCId = t.add_output(
    Output(
        "VPCId",
        Description="VPCId of the newly created VPC",
        Value=Ref(VPCResource),
    )
)

print(t.to_json())



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer
from .validators.route53 import AliasTarget  # noqa: F401


class Location(AWSProperty):
    """
    `Location <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53-cidrcollection-location.html>`__
    """

    props: PropsDictType = {
        "CidrList": ([str], True),
        "LocationName": (str, True),
    }


class CidrCollection(AWSObject):
    """
    `CidrCollection <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53-cidrcollection.html>`__
    """

    resource_type = "AWS::Route53::CidrCollection"

    props: PropsDictType = {
        "Locations": ([Location], False),
        "Name": (str, True),
    }


class DNSSEC(AWSObject):
    """
    `DNSSEC <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53-dnssec.html>`__
    """

    resource_type = "AWS::Route53::DNSSEC"

    props: PropsDictType = {
        "HostedZoneId": (str, True),
    }


class AlarmIdentifier(AWSProperty):
    """
    `AlarmIdentifier <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53-healthcheck-alarmidentifier.html>`__
    """

    props: PropsDictType = {
        "Name": (str, True),
        "Region": (str, True),
    }


class HealthCheckConfig(AWSProperty):
    """
    `HealthCheckConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53-healthcheck-healthcheckconfig.html>`__
    """

    props: PropsDictType = {
        "AlarmIdentifier": (AlarmIdentifier, False),
        "ChildHealthChecks": ([str], False),
        "EnableSNI": (boolean, False),
        "FailureThreshold": (integer, False),
        "FullyQualifiedDomainName": (str, False),
        "HealthThreshold": (integer, False),
        "IPAddress": (str, False),
        "InsufficientDataHealthStatus": (str, False),
        "Inverted": (boolean, False),
        "MeasureLatency": (boolean, False),
        "Port": (integer, False),
        "Regions": ([str], False),
        "RequestInterval": (integer, False),
        "ResourcePath": (str, False),
        "RoutingControlArn": (str, False),
        "SearchString": (str, False),
        "Type": (str, True),
    }


class HealthCheck(AWSObject):
    """
    `HealthCheck <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53-healthcheck.html>`__
    """

    resource_type = "AWS::Route53::HealthCheck"

    props: PropsDictType = {
        "HealthCheckConfig": (HealthCheckConfig, True),
        "HealthCheckTags": (Tags, False),
    }


class HostedZoneConfiguration(AWSProperty):
    """
    `HostedZoneConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53-hostedzone-hostedzoneconfig.html>`__
    """

    props: PropsDictType = {
        "Comment": (str, False),
    }


class HostedZoneVPCs(AWSProperty):
    """
    `HostedZoneVPCs <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53-hostedzone-vpc.html>`__
    """

    props: PropsDictType = {
        "VPCId": (str, True),
        "VPCRegion": (str, True),
    }


class QueryLoggingConfig(AWSProperty):
    """
    `QueryLoggingConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53-hostedzone-queryloggingconfig.html>`__
    """

    props: PropsDictType = {
        "CloudWatchLogsLogGroupArn": (str, True),
    }


class HostedZone(AWSObject):
    """
    `HostedZone <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53-hostedzone.html>`__
    """

    resource_type = "AWS::Route53::HostedZone"

    props: PropsDictType = {
        "HostedZoneConfig": (HostedZoneConfiguration, False),
        "HostedZoneTags": (Tags, False),
        "Name": (str, False),
        "QueryLoggingConfig": (QueryLoggingConfig, False),
        "VPCs": ([HostedZoneVPCs], False),
    }


class KeySigningKey(AWSObject):
    """
    `KeySigningKey <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53-keysigningkey.html>`__
    """

    resource_type = "AWS::Route53::KeySigningKey"

    props: PropsDictType = {
        "HostedZoneId": (str, True),
        "KeyManagementServiceArn": (str, True),
        "Name": (str, True),
        "Status": (str, True),
    }


class CidrRoutingConfig(AWSProperty):
    """
    `CidrRoutingConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53-cidrroutingconfig.html>`__
    """

    props: PropsDictType = {
        "CollectionId": (str, True),
        "LocationName": (str, True),
    }


class GeoLocation(AWSProperty):
    """
    `GeoLocation <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53-recordset-geolocation.html>`__
    """

    props: PropsDictType = {
        "ContinentCode": (str, False),
        "CountryCode": (str, False),
        "SubdivisionCode": (str, False),
    }


class RecordSet(AWSProperty):
    """
    `RecordSet <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53-recordset.html>`__
    """

    props: PropsDictType = {
        "AliasTarget": (AliasTarget, False),
        "CidrRoutingConfig": (CidrRoutingConfig, False),
        "Failover": (str, False),
        "GeoLocation": (GeoLocation, False),
        "HealthCheckId": (str, False),
        "HostedZoneId": (str, False),
        "HostedZoneName": (str, False),
        "MultiValueAnswer": (boolean, False),
        "Name": (str, True),
        "Region": (str, False),
        "ResourceRecords": ([str], False),
        "SetIdentifier": (str, False),
        "TTL": (str, False),
        "Type": (str, True),
        "Weight": (integer, False),
    }


class RecordSetGroup(AWSObject):
    """
    `RecordSetGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-route53-recordsetgroup.html>`__
    """

    resource_type = "AWS::Route53::RecordSetGroup"

    props: PropsDictType = {
        "Comment": (str, False),
        "HostedZoneId": (str, False),
        "HostedZoneName": (str, False),
        "RecordSets": ([RecordSet], False),
    }


class RecordSetType(AWSObject):
    """
    `RecordSetType <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-route53-recordset.html>`__
    """

    resource_type = "AWS::Route53::RecordSet"

    props: PropsDictType = {
        "AliasTarget": (AliasTarget, False),
        "CidrRoutingConfig": (CidrRoutingConfig, False),
        "Comment": (str, False),
        "Failover": (str, False),
        "GeoLocation": (GeoLocation, False),
        "HealthCheckId": (str, False),
        "HostedZoneId": (str, False),
        "HostedZoneName": (str, False),
        "MultiValueAnswer": (boolean, False),
        "Name": (str, True),
        "Region": (str, False),
        "ResourceRecords": ([str], False),
        "SetIdentifier": (str, False),
        "TTL": (str, False),
        "Type": (str, True),
        "Weight": (integer, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType
from .validators import boolean, integer
from .validators.secretsmanager import (
    policytypes,
    validate_tags_or_list,
    validate_target_types,
)


class ResourcePolicy(AWSObject):
    """
    `ResourcePolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-secretsmanager-resourcepolicy.html>`__
    """

    resource_type = "AWS::SecretsManager::ResourcePolicy"

    props: PropsDictType = {
        "BlockPublicPolicy": (boolean, False),
        "ResourcePolicy": (policytypes, True),
        "SecretId": (str, True),
    }


class HostedRotationLambda(AWSProperty):
    """
    `HostedRotationLambda <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-secretsmanager-rotationschedule-hostedrotationlambda.html>`__
    """

    props: PropsDictType = {
        "ExcludeCharacters": (str, False),
        "KmsKeyArn": (str, False),
        "MasterSecretArn": (str, False),
        "MasterSecretKmsKeyArn": (str, False),
        "RotationLambdaName": (str, False),
        "RotationType": (str, True),
        "Runtime": (str, False),
        "SuperuserSecretArn": (str, False),
        "SuperuserSecretKmsKeyArn": (str, False),
        "VpcSecurityGroupIds": (str, False),
        "VpcSubnetIds": (str, False),
    }


class RotationRules(AWSProperty):
    """
    `RotationRules <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-secretsmanager-rotationschedule-rotationrules.html>`__
    """

    props: PropsDictType = {
        "AutomaticallyAfterDays": (integer, False),
        "Duration": (str, False),
        "ScheduleExpression": (str, False),
    }


class RotationSchedule(AWSObject):
    """
    `RotationSchedule <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-secretsmanager-rotationschedule.html>`__
    """

    resource_type = "AWS::SecretsManager::RotationSchedule"

    props: PropsDictType = {
        "HostedRotationLambda": (HostedRotationLambda, False),
        "RotateImmediatelyOnUpdate": (boolean, False),
        "RotationLambdaARN": (str, False),
        "RotationRules": (RotationRules, False),
        "SecretId": (str, True),
    }


class GenerateSecretString(AWSProperty):
    """
    `GenerateSecretString <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-secretsmanager-secret-generatesecretstring.html>`__
    """

    props: PropsDictType = {
        "ExcludeCharacters": (str, False),
        "ExcludeLowercase": (boolean, False),
        "ExcludeNumbers": (boolean, False),
        "ExcludePunctuation": (boolean, False),
        "ExcludeUppercase": (boolean, False),
        "GenerateStringKey": (str, False),
        "IncludeSpace": (boolean, False),
        "PasswordLength": (integer, False),
        "RequireEachIncludedType": (boolean, False),
        "SecretStringTemplate": (str, False),
    }


class ReplicaRegion(AWSProperty):
    """
    `ReplicaRegion <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-secretsmanager-secret-replicaregion.html>`__
    """

    props: PropsDictType = {
        "KmsKeyId": (str, False),
        "Region": (str, True),
    }


class Secret(AWSObject):
    """
    `Secret <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-secretsmanager-secret.html>`__
    """

    resource_type = "AWS::SecretsManager::Secret"

    props: PropsDictType = {
        "Description": (str, False),
        "GenerateSecretString": (GenerateSecretString, False),
        "KmsKeyId": (str, False),
        "Name": (str, False),
        "ReplicaRegions": ([ReplicaRegion], False),
        "SecretString": (str, False),
        "Tags": (validate_tags_or_list, False),
    }


class SecretTargetAttachment(AWSObject):
    """
    `SecretTargetAttachment <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-secretsmanager-secrettargetattachment.html>`__
    """

    resource_type = "AWS::SecretsManager::SecretTargetAttachment"

    props: PropsDictType = {
        "SecretId": (str, True),
        "TargetId": (str, True),
        "TargetType": (validate_target_types, True),
    }



import unittest

import troposphere.ecs as ecs
from troposphere import Ref, iam


class TestECS(unittest.TestCase):
    def test_allow_placement_strategy_constraint(self):
        task_definition = ecs.TaskDefinition(
            "mytaskdef",
            ContainerDefinitions=[
                ecs.ContainerDefinition(
                    Image="myimage",
                    Memory="300",
                    Name="mycontainer",
                )
            ],
            Volumes=[
                ecs.Volume(Name="my-vol"),
            ],
        )
        ecs_service = ecs.Service(
            "Service",
            Cluster="cluster",
            DesiredCount=2,
            PlacementStrategies=[
                ecs.PlacementStrategy(
                    Type="random",
                )
            ],
            PlacementConstraints=[
                ecs.PlacementConstraint(
                    Type="distinctInstance",
                )
            ],
            TaskDefinition=Ref(task_definition),
        )

        ecs_service.to_dict()

    def test_allow_scheduling_strategy(self):
        task_definition = ecs.TaskDefinition(
            "mytaskdef",
            ContainerDefinitions=[
                ecs.ContainerDefinition(
                    Image="myimage",
                    Memory="300",
                    Name="mycontainer",
                )
            ],
            Volumes=[
                ecs.Volume(Name="my-vol"),
            ],
        )
        ecs_service = ecs.Service(
            "Service",
            Cluster="cluster",
            DesiredCount=2,
            TaskDefinition=Ref(task_definition),
            SchedulingStrategy=ecs.SCHEDULING_STRATEGY_DAEMON,
        )

        ecs_service.to_dict()

    def test_fargate_launch_type(self):
        task_definition = ecs.TaskDefinition(
            "mytaskdef",
            ContainerDefinitions=[
                ecs.ContainerDefinition(
                    Image="myimage",
                    Memory="300",
                    Name="mycontainer",
                )
            ],
            Volumes=[
                ecs.Volume(Name="my-vol"),
            ],
        )
        ecs_service = ecs.Service(
            "Service",
            Cluster="cluster",
            DesiredCount=2,
            PlacementStrategies=[
                ecs.PlacementStrategy(
                    Type="random",
                )
            ],
            LaunchType="FARGATE",
            NetworkConfiguration=ecs.NetworkConfiguration(
                AwsvpcConfiguration=ecs.AwsvpcConfiguration(
                    AssignPublicIp="DISABLED",
                    SecurityGroups=["sg-1234"],
                    Subnets=["subnet-1234"],
                )
            ),
            PlacementConstraints=[
                ecs.PlacementConstraint(
                    Type="distinctInstance",
                )
            ],
            TaskDefinition=Ref(task_definition),
        )

        ecs_service.to_dict()

    def test_allow_string_cluster(self):
        task_definition = ecs.TaskDefinition(
            "mytaskdef",
            ContainerDefinitions=[
                ecs.ContainerDefinition(
                    Image="myimage",
                    Memory="300",
                    Name="mycontainer",
                )
            ],
            Volumes=[
                ecs.Volume(Name="my-vol"),
            ],
        )
        ecs_service = ecs.Service(
            "Service",
            Cluster="cluster",
            DesiredCount=2,
            TaskDefinition=Ref(task_definition),
        )

        ecs_service.to_dict()

    def test_allow_ref_cluster(self):
        task_definition = ecs.TaskDefinition(
            "mytaskdef",
            ContainerDefinitions=[
                ecs.ContainerDefinition(
                    Image="myimage",
                    Memory="300",
                    Name="mycontainer",
                )
            ],
            Volumes=[
                ecs.Volume(Name="my-vol"),
            ],
        )
        cluster = ecs.Cluster("mycluster")
        ecs_service = ecs.Service(
            "Service",
            Cluster=Ref(cluster),
            DesiredCount=2,
            TaskDefinition=Ref(task_definition),
        )

        ecs_service.to_dict()

    def test_task_role_arn_is_optional(self):
        task_definition = ecs.TaskDefinition(
            "mytaskdef",
            ContainerDefinitions=[
                ecs.ContainerDefinition(
                    Image="myimage",
                    Memory="300",
                    Name="mycontainer",
                )
            ],
        )

        task_definition.to_dict()

    def test_allow_string_task_role_arn(self):
        task_definition = ecs.TaskDefinition(
            "mytaskdef",
            ContainerDefinitions=[
                ecs.ContainerDefinition(
                    Image="myimage",
                    Memory="300",
                    Name="mycontainer",
                )
            ],
            TaskRoleArn="myiamrole",
        )

        task_definition.to_dict()

    def test_allow_ref_task_role_arn(self):
        task_definition = ecs.TaskDefinition(
            "mytaskdef",
            ContainerDefinitions=[
                ecs.ContainerDefinition(
                    Image="myimage",
                    Memory="300",
                    Name="mycontainer",
                )
            ],
            TaskRoleArn=Ref(iam.Role("myRole")),
        )

        task_definition.to_dict()

    def test_allow_port_mapping_protocol(self):
        container_definition = ecs.ContainerDefinition(
            Image="myimage",
            Memory="300",
            Name="mycontainer",
            PortMappings=[
                ecs.PortMapping(ContainerPort=8125, HostPort=8125, Protocol="udp")
            ],
        )

        container_definition.to_dict()

    def test_port_mapping_does_not_require_protocol(self):
        container_definition = ecs.ContainerDefinition(
            Image="myimage",
            Memory="300",
            Name="mycontainer",
            PortMappings=[
                ecs.PortMapping(
                    ContainerPort=8125,
                    HostPort=8125,
                )
            ],
        )

        container_definition.to_dict()

    def test_allow_container_healthcheck(self):
        health_check_def = ecs.HealthCheck(
            Command=["CMD-SHELL", "curl -f http://localhost/ || exit 1"],
            Interval=5,
            Timeout=30,
            Retries=5,
        )
        container_definition = ecs.ContainerDefinition(
            Image="myimage",
            Memory="300",
            Name="mycontainer",
            HealthCheck=health_check_def,
        )

        container_definition.to_dict()

    def test_docker_volume_configuration(self):
        docker_volume_configuration = ecs.DockerVolumeConfiguration(
            Autoprovision=True,
            Scope="task",
            Labels=dict(label="ok"),
            DriverOpts=dict(option="ok"),
        )
        task_definition = ecs.TaskDefinition(
            "mytaskdef",
            ContainerDefinitions=[
                ecs.ContainerDefinition(
                    Image="myimage",
                    Memory="300",
                    Name="mycontainer",
                )
            ],
            Volumes=[
                ecs.Volume(
                    Name="my-vol", DockerVolumeConfiguration=docker_volume_configuration
                ),
            ],
        )
        task_definition.to_dict()


class TestECSValidators(unittest.TestCase):
    def test_scope_validator(self):
        valid_values = ["shared", "task"]
        for x in valid_values:
            ecs.scope_validator(x)

        with self.assertRaises(ValueError):
            ecs.scope_validator("bad_scope")

    def test_network_port(self):
        valid_values = [-1, 0, 65535]
        for x in valid_values:
            ecs.validate_network_port(x)

        invalid_values = [-2, 65536]
        for x in invalid_values:
            with self.assertRaises(ValueError):
                ecs.validate_network_port(x)

    def test_scaling_step_size(self):
        valid_values = [1, 100, 10000]
        for x in valid_values:
            ecs.validate_scaling_step_size(x)

        invalid_values = [-1, 0, 10001]
        for x in invalid_values:
            with self.assertRaises(ValueError):
                ecs.validate_scaling_step_size(x)



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.


from .. import AWSProperty
from . import boolean


class AliasTarget(AWSProperty):
    """
    Export:
    """

    props = {
        "HostedZoneId": (str, True),
        "DNSName": (str, True),
        "EvaluateTargetHealth": (boolean, False),
    }

    def __init__(
        self, hostedzoneid=None, dnsname=None, evaluatetargethealth=None, **kwargs
    ):
        # provided for backward compatibility
        if hostedzoneid is not None:
            kwargs["HostedZoneId"] = hostedzoneid
        if dnsname is not None:
            kwargs["DNSName"] = dnsname
        if evaluatetargethealth is not None:
            kwargs["EvaluateTargetHealth"] = evaluatetargethealth
        super().__init__(**kwargs)



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer


class Destination(AWSProperty):
    """
    `Destination <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudtrail-channel-destination.html>`__
    """

    props: PropsDictType = {
        "Location": (str, True),
        "Type": (str, True),
    }


class Channel(AWSObject):
    """
    `Channel <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudtrail-channel.html>`__
    """

    resource_type = "AWS::CloudTrail::Channel"

    props: PropsDictType = {
        "Destinations": ([Destination], False),
        "Name": (str, False),
        "Source": (str, False),
        "Tags": (Tags, False),
    }


class AdvancedFieldSelector(AWSProperty):
    """
    `AdvancedFieldSelector <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudtrail-trail-advancedfieldselector.html>`__
    """

    props: PropsDictType = {
        "EndsWith": ([str], False),
        "Equals": ([str], False),
        "Field": (str, True),
        "NotEndsWith": ([str], False),
        "NotEquals": ([str], False),
        "NotStartsWith": ([str], False),
        "StartsWith": ([str], False),
    }


class AdvancedEventSelector(AWSProperty):
    """
    `AdvancedEventSelector <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudtrail-trail-advancedeventselector.html>`__
    """

    props: PropsDictType = {
        "FieldSelectors": ([AdvancedFieldSelector], True),
        "Name": (str, False),
    }


class InsightSelector(AWSProperty):
    """
    `InsightSelector <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudtrail-trail-insightselector.html>`__
    """

    props: PropsDictType = {
        "InsightType": (str, False),
    }


class EventDataStore(AWSObject):
    """
    `EventDataStore <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudtrail-eventdatastore.html>`__
    """

    resource_type = "AWS::CloudTrail::EventDataStore"

    props: PropsDictType = {
        "AdvancedEventSelectors": ([AdvancedEventSelector], False),
        "BillingMode": (str, False),
        "FederationEnabled": (boolean, False),
        "FederationRoleArn": (str, False),
        "IngestionEnabled": (boolean, False),
        "InsightSelectors": ([InsightSelector], False),
        "InsightsDestination": (str, False),
        "KmsKeyId": (str, False),
        "MultiRegionEnabled": (boolean, False),
        "Name": (str, False),
        "OrganizationEnabled": (boolean, False),
        "RetentionPeriod": (integer, False),
        "Tags": (Tags, False),
        "TerminationProtectionEnabled": (boolean, False),
    }


class ResourcePolicy(AWSObject):
    """
    `ResourcePolicy <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudtrail-resourcepolicy.html>`__
    """

    resource_type = "AWS::CloudTrail::ResourcePolicy"

    props: PropsDictType = {
        "ResourceArn": (str, True),
        "ResourcePolicy": (dict, True),
    }


class DataResource(AWSProperty):
    """
    `DataResource <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudtrail-trail-dataresource.html>`__
    """

    props: PropsDictType = {
        "Type": (str, True),
        "Values": ([str], False),
    }


class EventSelector(AWSProperty):
    """
    `EventSelector <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-cloudtrail-trail-eventselector.html>`__
    """

    props: PropsDictType = {
        "DataResources": ([DataResource], False),
        "ExcludeManagementEventSources": ([str], False),
        "IncludeManagementEvents": (boolean, False),
        "ReadWriteType": (str, False),
    }


class Trail(AWSObject):
    """
    `Trail <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-cloudtrail-trail.html>`__
    """

    resource_type = "AWS::CloudTrail::Trail"

    props: PropsDictType = {
        "AdvancedEventSelectors": ([AdvancedEventSelector], False),
        "CloudWatchLogsLogGroupArn": (str, False),
        "CloudWatchLogsRoleArn": (str, False),
        "EnableLogFileValidation": (boolean, False),
        "EventSelectors": ([EventSelector], False),
        "IncludeGlobalServiceEvents": (boolean, False),
        "InsightSelectors": ([InsightSelector], False),
        "IsLogging": (boolean, True),
        "IsMultiRegionTrail": (boolean, False),
        "IsOrganizationTrail": (boolean, False),
        "KMSKeyId": (str, False),
        "S3BucketName": (str, True),
        "S3KeyPrefix": (str, False),
        "SnsTopicName": (str, False),
        "Tags": (Tags, False),
        "TrailName": (str, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags


class EncryptionConfig(AWSProperty):
    """
    `EncryptionConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-forecast-dataset-encryptionconfig.html>`__
    """

    props: PropsDictType = {
        "KmsKeyArn": (str, False),
        "RoleArn": (str, False),
    }


class AttributesItems(AWSProperty):
    """
    `AttributesItems <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-forecast-dataset-attributesitems.html>`__
    """

    props: PropsDictType = {
        "AttributeName": (str, False),
        "AttributeType": (str, False),
    }


class Schema(AWSProperty):
    """
    `Schema <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-forecast-dataset-schema.html>`__
    """

    props: PropsDictType = {
        "Attributes": ([AttributesItems], False),
    }


class TagsItems(AWSProperty):
    """
    `TagsItems <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-forecast-dataset-tagsitems.html>`__
    """

    props: PropsDictType = {
        "Key": (str, True),
        "Value": (str, True),
    }


class Dataset(AWSObject):
    """
    `Dataset <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-forecast-dataset.html>`__
    """

    resource_type = "AWS::Forecast::Dataset"

    props: PropsDictType = {
        "DataFrequency": (str, False),
        "DatasetName": (str, True),
        "DatasetType": (str, True),
        "Domain": (str, True),
        "EncryptionConfig": (EncryptionConfig, False),
        "Schema": (Schema, True),
        "Tags": ([TagsItems], False),
    }


class DatasetGroup(AWSObject):
    """
    `DatasetGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-forecast-datasetgroup.html>`__
    """

    resource_type = "AWS::Forecast::DatasetGroup"

    props: PropsDictType = {
        "DatasetArns": ([str], False),
        "DatasetGroupName": (str, True),
        "Domain": (str, True),
        "Tags": (Tags, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer
from .validators.elasticache import (
    validate_cache_cluster,
    validate_network_port,
    validate_node_group_id,
    validate_replication_group,
)


class CloudWatchLogsDestinationDetails(AWSProperty):
    """
    `CloudWatchLogsDestinationDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-replicationgroup-cloudwatchlogsdestinationdetails.html>`__
    """

    props: PropsDictType = {
        "LogGroup": (str, True),
    }


class KinesisFirehoseDestinationDetails(AWSProperty):
    """
    `KinesisFirehoseDestinationDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-replicationgroup-kinesisfirehosedestinationdetails.html>`__
    """

    props: PropsDictType = {
        "DeliveryStream": (str, True),
    }


class DestinationDetails(AWSProperty):
    """
    `DestinationDetails <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-replicationgroup-destinationdetails.html>`__
    """

    props: PropsDictType = {
        "CloudWatchLogsDetails": (CloudWatchLogsDestinationDetails, False),
        "KinesisFirehoseDetails": (KinesisFirehoseDestinationDetails, False),
    }


class LogDeliveryConfigurationRequest(AWSProperty):
    """
    `LogDeliveryConfigurationRequest <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-replicationgroup-logdeliveryconfigurationrequest.html>`__
    """

    props: PropsDictType = {
        "DestinationDetails": (DestinationDetails, True),
        "DestinationType": (str, True),
        "LogFormat": (str, True),
        "LogType": (str, True),
    }


class CacheCluster(AWSObject):
    """
    `CacheCluster <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-cache-cluster.html>`__
    """

    resource_type = "AWS::ElastiCache::CacheCluster"

    props: PropsDictType = {
        "AZMode": (str, False),
        "AutoMinorVersionUpgrade": (boolean, False),
        "CacheNodeType": (str, True),
        "CacheParameterGroupName": (str, False),
        "CacheSecurityGroupNames": ([str], False),
        "CacheSubnetGroupName": (str, False),
        "ClusterName": (str, False),
        "Engine": (str, True),
        "EngineVersion": (str, False),
        "IpDiscovery": (str, False),
        "LogDeliveryConfigurations": ([LogDeliveryConfigurationRequest], False),
        "NetworkType": (str, False),
        "NotificationTopicArn": (str, False),
        "NumCacheNodes": (integer, True),
        "Port": (integer, False),
        "PreferredAvailabilityZone": (str, False),
        "PreferredAvailabilityZones": ([str], False),
        "PreferredMaintenanceWindow": (str, False),
        "SnapshotArns": ([str], False),
        "SnapshotName": (str, False),
        "SnapshotRetentionLimit": (integer, False),
        "SnapshotWindow": (str, False),
        "Tags": (Tags, False),
        "TransitEncryptionEnabled": (boolean, False),
        "VpcSecurityGroupIds": ([str], False),
    }

    def validate(self):
        validate_cache_cluster(self)


class GlobalReplicationGroupMember(AWSProperty):
    """
    `GlobalReplicationGroupMember <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-globalreplicationgroup-globalreplicationgroupmember.html>`__
    """

    props: PropsDictType = {
        "ReplicationGroupId": (str, False),
        "ReplicationGroupRegion": (str, False),
        "Role": (str, False),
    }


class ReshardingConfiguration(AWSProperty):
    """
    `ReshardingConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-globalreplicationgroup-reshardingconfiguration.html>`__
    """

    props: PropsDictType = {
        "NodeGroupId": (str, False),
        "PreferredAvailabilityZones": ([str], False),
    }


class RegionalConfiguration(AWSProperty):
    """
    `RegionalConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-globalreplicationgroup-regionalconfiguration.html>`__
    """

    props: PropsDictType = {
        "ReplicationGroupId": (str, False),
        "ReplicationGroupRegion": (str, False),
        "ReshardingConfigurations": ([ReshardingConfiguration], False),
    }


class GlobalReplicationGroup(AWSObject):
    """
    `GlobalReplicationGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticache-globalreplicationgroup.html>`__
    """

    resource_type = "AWS::ElastiCache::GlobalReplicationGroup"

    props: PropsDictType = {
        "AutomaticFailoverEnabled": (boolean, False),
        "CacheNodeType": (str, False),
        "CacheParameterGroupName": (str, False),
        "EngineVersion": (str, False),
        "GlobalNodeGroupCount": (integer, False),
        "GlobalReplicationGroupDescription": (str, False),
        "GlobalReplicationGroupIdSuffix": (str, False),
        "Members": ([GlobalReplicationGroupMember], True),
        "RegionalConfigurations": ([RegionalConfiguration], False),
    }


class ParameterGroup(AWSObject):
    """
    `ParameterGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-parameter-group.html>`__
    """

    resource_type = "AWS::ElastiCache::ParameterGroup"

    props: PropsDictType = {
        "CacheParameterGroupFamily": (str, True),
        "Description": (str, True),
        "Properties": (dict, False),
        "Tags": (Tags, False),
    }


class NodeGroupConfiguration(AWSProperty):
    """
    `NodeGroupConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-replicationgroup-nodegroupconfiguration.html>`__
    """

    props: PropsDictType = {
        "NodeGroupId": (validate_node_group_id, False),
        "PrimaryAvailabilityZone": (str, False),
        "ReplicaAvailabilityZones": ([str], False),
        "ReplicaCount": (integer, False),
        "Slots": (str, False),
    }


class ReplicationGroup(AWSObject):
    """
    `ReplicationGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticache-replicationgroup.html>`__
    """

    resource_type = "AWS::ElastiCache::ReplicationGroup"

    props: PropsDictType = {
        "AtRestEncryptionEnabled": (boolean, False),
        "AuthToken": (str, False),
        "AutoMinorVersionUpgrade": (boolean, False),
        "AutomaticFailoverEnabled": (boolean, False),
        "CacheNodeType": (str, False),
        "CacheParameterGroupName": (str, False),
        "CacheSecurityGroupNames": ([str], False),
        "CacheSubnetGroupName": (str, False),
        "ClusterMode": (str, False),
        "DataTieringEnabled": (boolean, False),
        "Engine": (str, False),
        "EngineVersion": (str, False),
        "GlobalReplicationGroupId": (str, False),
        "IpDiscovery": (str, False),
        "KmsKeyId": (str, False),
        "LogDeliveryConfigurations": ([LogDeliveryConfigurationRequest], False),
        "MultiAZEnabled": (boolean, False),
        "NetworkType": (str, False),
        "NodeGroupConfiguration": ([NodeGroupConfiguration], False),
        "NotificationTopicArn": (str, False),
        "NumCacheClusters": (integer, False),
        "NumNodeGroups": (integer, False),
        "Port": (validate_network_port, False),
        "PreferredCacheClusterAZs": ([str], False),
        "PreferredMaintenanceWindow": (str, False),
        "PrimaryClusterId": (str, False),
        "ReplicasPerNodeGroup": (integer, False),
        "ReplicationGroupDescription": (str, True),
        "ReplicationGroupId": (str, False),
        "SecurityGroupIds": ([str], False),
        "SnapshotArns": ([str], False),
        "SnapshotName": (str, False),
        "SnapshotRetentionLimit": (integer, False),
        "SnapshotWindow": (str, False),
        "SnapshottingClusterId": (str, False),
        "Tags": (Tags, False),
        "TransitEncryptionEnabled": (boolean, False),
        "TransitEncryptionMode": (str, False),
        "UserGroupIds": ([str], False),
    }

    def validate(self):
        validate_replication_group(self)


class SecurityGroup(AWSObject):
    """
    `SecurityGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-security-group.html>`__
    """

    resource_type = "AWS::ElastiCache::SecurityGroup"

    props: PropsDictType = {
        "Description": (str, True),
        "Tags": (Tags, False),
    }


class SecurityGroupIngress(AWSObject):
    """
    `SecurityGroupIngress <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-security-group-ingress.html>`__
    """

    resource_type = "AWS::ElastiCache::SecurityGroupIngress"

    props: PropsDictType = {
        "CacheSecurityGroupName": (str, True),
        "EC2SecurityGroupName": (str, True),
        "EC2SecurityGroupOwnerId": (str, False),
    }


class DataStorage(AWSProperty):
    """
    `DataStorage <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-serverlesscache-datastorage.html>`__
    """

    props: PropsDictType = {
        "Maximum": (integer, True),
        "Unit": (str, True),
    }


class ECPUPerSecond(AWSProperty):
    """
    `ECPUPerSecond <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-serverlesscache-ecpupersecond.html>`__
    """

    props: PropsDictType = {
        "Maximum": (integer, True),
    }


class CacheUsageLimits(AWSProperty):
    """
    `CacheUsageLimits <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-serverlesscache-cacheusagelimits.html>`__
    """

    props: PropsDictType = {
        "DataStorage": (DataStorage, False),
        "ECPUPerSecond": (ECPUPerSecond, False),
    }


class Endpoint(AWSProperty):
    """
    `Endpoint <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-serverlesscache-endpoint.html>`__
    """

    props: PropsDictType = {
        "Address": (str, False),
        "Port": (validate_network_port, False),
    }


class ServerlessCache(AWSObject):
    """
    `ServerlessCache <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticache-serverlesscache.html>`__
    """

    resource_type = "AWS::ElastiCache::ServerlessCache"

    props: PropsDictType = {
        "CacheUsageLimits": (CacheUsageLimits, False),
        "DailySnapshotTime": (str, False),
        "Description": (str, False),
        "Endpoint": (Endpoint, False),
        "Engine": (str, True),
        "FinalSnapshotName": (str, False),
        "KmsKeyId": (str, False),
        "MajorEngineVersion": (str, False),
        "ReaderEndpoint": (Endpoint, False),
        "SecurityGroupIds": ([str], False),
        "ServerlessCacheName": (str, True),
        "SnapshotArnsToRestore": ([str], False),
        "SnapshotRetentionLimit": (integer, False),
        "SubnetIds": ([str], False),
        "Tags": (Tags, False),
        "UserGroupId": (str, False),
    }


class SubnetGroup(AWSObject):
    """
    `SubnetGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticache-subnetgroup.html>`__
    """

    resource_type = "AWS::ElastiCache::SubnetGroup"

    props: PropsDictType = {
        "CacheSubnetGroupName": (str, False),
        "Description": (str, True),
        "SubnetIds": ([str], True),
        "Tags": (Tags, False),
    }


class AuthenticationMode(AWSProperty):
    """
    `AuthenticationMode <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-elasticache-user-authenticationmode.html>`__
    """

    props: PropsDictType = {
        "Passwords": ([str], False),
        "Type": (str, True),
    }


class User(AWSObject):
    """
    `User <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticache-user.html>`__
    """

    resource_type = "AWS::ElastiCache::User"

    props: PropsDictType = {
        "AccessString": (str, False),
        "AuthenticationMode": (AuthenticationMode, False),
        "Engine": (str, True),
        "NoPasswordRequired": (boolean, False),
        "Passwords": ([str], False),
        "Tags": (Tags, False),
        "UserId": (str, True),
        "UserName": (str, True),
    }


class UserGroup(AWSObject):
    """
    `UserGroup <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-elasticache-usergroup.html>`__
    """

    resource_type = "AWS::ElastiCache::UserGroup"

    props: PropsDictType = {
        "Engine": (str, True),
        "Tags": (Tags, False),
        "UserGroupId": (str, True),
        "UserIds": ([str], True),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, PropsDictType
from .validators import boolean
from .validators.chatbot import validate_logginglevel


class MicrosoftTeamsChannelConfiguration(AWSObject):
    """
    `MicrosoftTeamsChannelConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-chatbot-microsoftteamschannelconfiguration.html>`__
    """

    resource_type = "AWS::Chatbot::MicrosoftTeamsChannelConfiguration"

    props: PropsDictType = {
        "ConfigurationName": (str, True),
        "GuardrailPolicies": ([str], False),
        "IamRoleArn": (str, True),
        "LoggingLevel": (str, False),
        "SnsTopicArns": ([str], False),
        "TeamId": (str, True),
        "TeamsChannelId": (str, True),
        "TeamsTenantId": (str, True),
        "UserRoleRequired": (boolean, False),
    }


class SlackChannelConfiguration(AWSObject):
    """
    `SlackChannelConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-chatbot-slackchannelconfiguration.html>`__
    """

    resource_type = "AWS::Chatbot::SlackChannelConfiguration"

    props: PropsDictType = {
        "ConfigurationName": (str, True),
        "GuardrailPolicies": ([str], False),
        "IamRoleArn": (str, True),
        "LoggingLevel": (validate_logginglevel, False),
        "SlackChannelId": (str, True),
        "SlackWorkspaceId": (str, True),
        "SnsTopicArns": ([str], False),
        "UserRoleRequired": (boolean, False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, PropsDictType, Tags
from .validators.codestarconnections import validate_connection_providertype


class Connection(AWSObject):
    """
    `Connection <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarconnections-connection.html>`__
    """

    resource_type = "AWS::CodeStarConnections::Connection"

    props: PropsDictType = {
        "ConnectionName": (str, True),
        "HostArn": (str, False),
        "ProviderType": (validate_connection_providertype, False),
        "Tags": (Tags, False),
    }


class RepositoryLink(AWSObject):
    """
    `RepositoryLink <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarconnections-repositorylink.html>`__
    """

    resource_type = "AWS::CodeStarConnections::RepositoryLink"

    props: PropsDictType = {
        "ConnectionArn": (str, True),
        "EncryptionKeyArn": (str, False),
        "OwnerId": (str, True),
        "RepositoryName": (str, True),
        "Tags": (Tags, False),
    }


class SyncConfiguration(AWSObject):
    """
    `SyncConfiguration <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-codestarconnections-syncconfiguration.html>`__
    """

    resource_type = "AWS::CodeStarConnections::SyncConfiguration"

    props: PropsDictType = {
        "Branch": (str, True),
        "ConfigFile": (str, True),
        "RepositoryLinkId": (str, True),
        "ResourceName": (str, True),
        "RoleArn": (str, True),
        "SyncType": (str, True),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, PropsDictType, Tags
from .validators import integer


class Cluster(AWSObject):
    """
    `Cluster <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-docdbelastic-cluster.html>`__
    """

    resource_type = "AWS::DocDBElastic::Cluster"

    props: PropsDictType = {
        "AdminUserName": (str, True),
        "AdminUserPassword": (str, False),
        "AuthType": (str, True),
        "ClusterName": (str, True),
        "KmsKeyId": (str, False),
        "PreferredMaintenanceWindow": (str, False),
        "ShardCapacity": (integer, True),
        "ShardCount": (integer, True),
        "SubnetIds": ([str], False),
        "Tags": (Tags, False),
        "VpcSecurityGroupIds": ([str], False),
    }



# Copyright (c) 2012-2022, Mark Peek <mark@peek.org>
# All rights reserved.
#
# See LICENSE file for full license.
#
# *** Do not modify - this file is autogenerated ***


from . import AWSObject, AWSProperty, PropsDictType, Tags
from .validators import boolean, integer
from .validators.opensearchservice import validate_search_service_engine_version


class MasterUserOptions(AWSProperty):
    """
    `MasterUserOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-masteruseroptions.html>`__
    """

    props: PropsDictType = {
        "MasterUserARN": (str, False),
        "MasterUserName": (str, False),
        "MasterUserPassword": (str, False),
    }


class Idp(AWSProperty):
    """
    `Idp <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-idp.html>`__
    """

    props: PropsDictType = {
        "EntityId": (str, True),
        "MetadataContent": (str, True),
    }


class SAMLOptions(AWSProperty):
    """
    `SAMLOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-samloptions.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, False),
        "Idp": (Idp, False),
        "MasterBackendRole": (str, False),
        "MasterUserName": (str, False),
        "RolesKey": (str, False),
        "SessionTimeoutMinutes": (integer, False),
        "SubjectKey": (str, False),
    }


class AdvancedSecurityOptionsInput(AWSProperty):
    """
    `AdvancedSecurityOptionsInput <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-advancedsecurityoptionsinput.html>`__
    """

    props: PropsDictType = {
        "AnonymousAuthDisableDate": (str, False),
        "AnonymousAuthEnabled": (boolean, False),
        "Enabled": (boolean, False),
        "InternalUserDatabaseEnabled": (boolean, False),
        "MasterUserOptions": (MasterUserOptions, False),
        "SAMLOptions": (SAMLOptions, False),
    }


class ColdStorageOptions(AWSProperty):
    """
    `ColdStorageOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-coldstorageoptions.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, False),
    }


class ZoneAwarenessConfig(AWSProperty):
    """
    `ZoneAwarenessConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-zoneawarenessconfig.html>`__
    """

    props: PropsDictType = {
        "AvailabilityZoneCount": (integer, False),
    }


class ClusterConfig(AWSProperty):
    """
    `ClusterConfig <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-clusterconfig.html>`__
    """

    props: PropsDictType = {
        "ColdStorageOptions": (ColdStorageOptions, False),
        "DedicatedMasterCount": (integer, False),
        "DedicatedMasterEnabled": (boolean, False),
        "DedicatedMasterType": (str, False),
        "InstanceCount": (integer, False),
        "InstanceType": (str, False),
        "MultiAZWithStandbyEnabled": (boolean, False),
        "WarmCount": (integer, False),
        "WarmEnabled": (boolean, False),
        "WarmType": (str, False),
        "ZoneAwarenessConfig": (ZoneAwarenessConfig, False),
        "ZoneAwarenessEnabled": (boolean, False),
    }


class CognitoOptions(AWSProperty):
    """
    `CognitoOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-cognitooptions.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, False),
        "IdentityPoolId": (str, False),
        "RoleArn": (str, False),
        "UserPoolId": (str, False),
    }


class DomainEndpointOptions(AWSProperty):
    """
    `DomainEndpointOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-domainendpointoptions.html>`__
    """

    props: PropsDictType = {
        "CustomEndpoint": (str, False),
        "CustomEndpointCertificateArn": (str, False),
        "CustomEndpointEnabled": (boolean, False),
        "EnforceHTTPS": (boolean, False),
        "TLSSecurityPolicy": (str, False),
    }


class EBSOptions(AWSProperty):
    """
    `EBSOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-ebsoptions.html>`__
    """

    props: PropsDictType = {
        "EBSEnabled": (boolean, False),
        "Iops": (integer, False),
        "Throughput": (integer, False),
        "VolumeSize": (integer, False),
        "VolumeType": (str, False),
    }


class EncryptionAtRestOptions(AWSProperty):
    """
    `EncryptionAtRestOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-encryptionatrestoptions.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, False),
        "KmsKeyId": (str, False),
    }


class LogPublishingOption(AWSProperty):
    """
    `LogPublishingOption <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-logpublishingoption.html>`__
    """

    props: PropsDictType = {
        "CloudWatchLogsLogGroupArn": (str, False),
        "Enabled": (boolean, False),
    }


class NodeToNodeEncryptionOptions(AWSProperty):
    """
    `NodeToNodeEncryptionOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-nodetonodeencryptionoptions.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, False),
    }


class WindowStartTime(AWSProperty):
    """
    `WindowStartTime <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-windowstarttime.html>`__
    """

    props: PropsDictType = {
        "Hours": (integer, True),
        "Minutes": (integer, True),
    }


class OffPeakWindow(AWSProperty):
    """
    `OffPeakWindow <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-offpeakwindow.html>`__
    """

    props: PropsDictType = {
        "WindowStartTime": (WindowStartTime, False),
    }


class OffPeakWindowOptions(AWSProperty):
    """
    `OffPeakWindowOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-offpeakwindowoptions.html>`__
    """

    props: PropsDictType = {
        "Enabled": (boolean, False),
        "OffPeakWindow": (OffPeakWindow, False),
    }


class SnapshotOptions(AWSProperty):
    """
    `SnapshotOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-snapshotoptions.html>`__
    """

    props: PropsDictType = {
        "AutomatedSnapshotStartHour": (integer, False),
    }


class SoftwareUpdateOptions(AWSProperty):
    """
    `SoftwareUpdateOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-softwareupdateoptions.html>`__
    """

    props: PropsDictType = {
        "AutoSoftwareUpdateEnabled": (boolean, False),
    }


class VPCOptions(AWSProperty):
    """
    `VPCOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-vpcoptions.html>`__
    """

    props: PropsDictType = {
        "SecurityGroupIds": ([str], False),
        "SubnetIds": ([str], False),
    }


class Domain(AWSObject):
    """
    `Domain <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-opensearchservice-domain.html>`__
    """

    resource_type = "AWS::OpenSearchService::Domain"

    props: PropsDictType = {
        "AccessPolicies": (dict, False),
        "AdvancedOptions": (dict, False),
        "AdvancedSecurityOptions": (AdvancedSecurityOptionsInput, False),
        "ClusterConfig": (ClusterConfig, False),
        "CognitoOptions": (CognitoOptions, False),
        "DomainEndpointOptions": (DomainEndpointOptions, False),
        "DomainName": (str, False),
        "EBSOptions": (EBSOptions, False),
        "EncryptionAtRestOptions": (EncryptionAtRestOptions, False),
        "EngineVersion": (validate_search_service_engine_version, False),
        "IPAddressType": (str, False),
        "LogPublishingOptions": (dict, False),
        "NodeToNodeEncryptionOptions": (NodeToNodeEncryptionOptions, False),
        "OffPeakWindowOptions": (OffPeakWindowOptions, False),
        "SnapshotOptions": (SnapshotOptions, False),
        "SoftwareUpdateOptions": (SoftwareUpdateOptions, False),
        "Tags": (Tags, False),
        "VPCOptions": (VPCOptions, False),
    }


class ServiceSoftwareOptions(AWSProperty):
    """
    `ServiceSoftwareOptions <http://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-opensearchservice-domain-servicesoftwareoptions.html>`__
    """

    props: PropsDictType = {
        "AutomatedUpdateDate": (str, False),
        "Cancellable": (boolean, False),
        "CurrentVersion": (str, False),
        "Description": (str, False),
        "NewVersion": (str, False),
        "OptionalDeployment": (boolean, False),
        "UpdateAvailable": (boolean, False),
        "UpdateStatus": (str, False),
    }
